@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -74,7 +74,7 @@ ArrangeSwapList(RectBox * list, int a, int b)
 void
 ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     int floating_count, RectBox * sorted, int startx, int starty,
-	     int width, int height, int policy)
+	     int width, int height, int policy, char initial_window)
 {
    int                 num_sorted = 0;
    int                 xsize = 0, ysize = 0;
@@ -90,6 +90,59 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 
    EDBUG(7, "ArrangeRects");
 
+#ifdef HAS_XINERAMA
+   if (initial_window)
+     {
+	if (xinerama_active)
+	  {
+	     Window              rt, ch;
+	     int                 d;
+	     unsigned int        ud;
+	     int                 pointer_x, pointer_y;
+	     int                 num;
+	     XineramaScreenInfo *screens;
+
+	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y,
+			   &d, &d, &ud);
+
+	     screens = XineramaQueryScreens(disp, &num);
+	     for (i = 0; i < num; i++)
+	       {
+		  if (pointer_x >= screens[i].x_org)
+		    {
+		       if (pointer_x <= (screens[i].width + screens[i].x_org))
+			 {
+			    if (pointer_y >= screens[i].y_org)
+			      {
+				 if (pointer_y <= (screens[i].height +
+						   screens[i].y_org))
+				   {
+				      if (screens[i].x_org > startx)
+					 startx = screens[i].x_org;
+				      if ((screens[i].x_org + screens[i].width)
+					  < width)
+					 width =
+					    screens[i].x_org + screens[i].width;
+				      if (screens[i].y_org > starty)
+					 starty = screens[i].y_org;
+				      if ((screens[i].y_org + screens[i].height)
+					  < height)
+					 height =
+					    screens[i].y_org +
+					    screens[i].height;
+				   }
+			      }
+			 }
+		    }
+	       }
+
+	     XFree(screens);
+	  }
+     }
+#else
+   initial_window = 0;
+#endif
+
    switch (policy)
      {
      case ARRANGE_VERBATIM:
@@ -210,11 +263,13 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     if (sorted[j].x < width)
 		xsize = ArrangeAddToList(&xarray, xsize, sorted[j].x);
 	     if ((sorted[j].x + sorted[j].w) < width)
-		xsize = ArrangeAddToList(&xarray, xsize, sorted[j].x + sorted[j].w);
+		xsize =
+		   ArrangeAddToList(&xarray, xsize, sorted[j].x + sorted[j].w);
 	     if (sorted[j].y < height)
 		ysize = ArrangeAddToList(&yarray, ysize, sorted[j].y);
 	     if ((sorted[j].y + sorted[j].h) < height)
-		ysize = ArrangeAddToList(&yarray, ysize, sorted[j].y + sorted[j].h);
+		ysize =
+		   ArrangeAddToList(&yarray, ysize, sorted[j].y + sorted[j].h);
 	  }
 /* fill the allocation array */
 	for (j = 0; j < (xsize - 1) * (ysize - 1); filled[j++] = 0);
@@ -250,7 +305,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		    {
 		       for (x = x1; x <= x2; x++)
 			 {
-			    if (filled[(y * (xsize - 1)) + x] < (sorted[j].p + 1))
+			    if (filled[(y * (xsize - 1)) + x] <
+				(sorted[j].p + 1))
 			       filled[(y * (xsize - 1)) + x] = sorted[j].p + 1;
 			 }
 		    }
@@ -321,27 +377,45 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     if ((spaces[j].w >= floating[i].w) &&
 		 (spaces[j].h >= floating[i].h))
 	       {
-		  if (policy == ARRANGE_BY_POSITION)
+		  if (spaces[j].x >= startx)
 		    {
-		       a1 = (spaces[j].x + (spaces[j].w >> 1)) -
-			  (floating[i].x + (floating[i].w >> 1));
-		       a2 = (spaces[j].y + (spaces[j].h >> 1)) -
-			  (floating[i].y + (floating[i].h >> 1));
-		       if (a1 < 0)
-			  a1 = -a1;
-		       if (a2 < 0)
-			  a2 = -a2;
-		       if ((a1 + a2) < sort)
+		       if ((spaces[j].x + spaces[j].w) <= width)
 			 {
-			    sort = a1 + a2;
-			    k = j;
+			    if (spaces[j].y >= starty)
+			      {
+				 if ((spaces[j].y + spaces[j].h) <= height)
+				   {
+				      if (policy == ARRANGE_BY_POSITION)
+					{
+					   a1 =
+					      (spaces[j].x +
+					       (spaces[j].w >> 1)) -
+					      (floating[i].x +
+					       (floating[i].w >> 1));
+					   a2 =
+					      (spaces[j].y +
+					       (spaces[j].h >> 1)) -
+					      (floating[i].y +
+					       (floating[i].h >> 1));
+					   if (a1 < 0)
+					      a1 = -a1;
+					   if (a2 < 0)
+					      a2 = -a2;
+					   if ((a1 + a2) < sort)
+					     {
+						sort = a1 + a2;
+						k = j;
+					     }
+					}
+				      else
+					{
+					   k = j;
+					   j = num_spaces;
+					}
+				   }
+			      }
 			 }
 		    }
-		  else
-		    {
-		       k = j;
-		       j = num_spaces;
-		    }
 	       }
 	  }
 	if (k >= 0)
@@ -353,13 +427,23 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		  a2 = (spaces[k].y + (spaces[k].h >> 1)) -
 		     (floating[i].y + (floating[i].h >> 1));
 		  if (a1 >= 0)
-		     sorted[num_sorted].x = spaces[k].x;
+		    {
+		       sorted[num_sorted].x = spaces[k].x;
+		    }
 		  else
-		     sorted[num_sorted].x = spaces[k].x + spaces[k].w - floating[i].w;
+		    {
+		       sorted[num_sorted].x =
+			  spaces[k].x + spaces[k].w - floating[i].w;
+		    }
 		  if (a2 >= 0)
-		     sorted[num_sorted].y = spaces[k].y;
+		    {
+		       sorted[num_sorted].y = spaces[k].y;
+		    }
 		  else
-		     sorted[num_sorted].y = spaces[k].y + spaces[k].h - floating[i].h;
+		    {
+		       sorted[num_sorted].y =
+			  spaces[k].y + spaces[k].h - floating[i].h;
+		    }
 	       }
 	     else
 	       {
@@ -375,13 +459,14 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	else
 	   leftover[num_leftover++] = i;
      }
-/* ok we cant fit everything in this baby.... time fit the leftovers into the */
-/* leftover space */
+
+   /* ok we cant fit everything in this baby.... time fit */
+   /*the leftovers into the leftover space */
    for (i = 0; i < num_leftover; i++)
      {
 	xsize = 0;
 	ysize = 0;
-/* put all the sorted rects into the xy arrays */
+	/* put all the sorted rects into the xy arrays */
 	xsize = ArrangeAddToList(&xarray, xsize, 0);
 	xsize = ArrangeAddToList(&xarray, xsize, width);
 	ysize = ArrangeAddToList(&yarray, ysize, 0);
@@ -391,13 +476,15 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     if (sorted[j].x < width)
 		xsize = ArrangeAddToList(&xarray, xsize, sorted[j].x);
 	     if ((sorted[j].x + sorted[j].w) < width)
-		xsize = ArrangeAddToList(&xarray, xsize, sorted[j].x + sorted[j].w);
+		xsize =
+		   ArrangeAddToList(&xarray, xsize, sorted[j].x + sorted[j].w);
 	     if (sorted[j].y < height)
 		ysize = ArrangeAddToList(&yarray, ysize, sorted[j].y);
 	     if ((sorted[j].y + sorted[j].h) < height)
-		ysize = ArrangeAddToList(&yarray, ysize, sorted[j].y + sorted[j].h);
+		ysize =
+		   ArrangeAddToList(&yarray, ysize, sorted[j].y + sorted[j].h);
 	  }
-/* fill the allocation array */
+	/* fill the allocation array */
 	for (j = 0; j < (xsize - 1) * (ysize - 1); filled[j++] = 0);
 	for (j = 0; j < num_sorted; j++)
 	  {
@@ -431,19 +518,20 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		    {
 		       for (x = x1; x <= x2; x++)
 			 {
-			    if (filled[(y * (xsize - 1)) + x] < (sorted[j].p + 1))
+			    if (filled[(y * (xsize - 1)) + x] <
+				(sorted[j].p + 1))
 			       filled[(y * (xsize - 1)) + x] = sorted[j].p + 1;
 			 }
 		    }
 	       }
 	  }
 	num_spaces = 0;
-/* create list of all "spaces" */
+	/* create list of all "spaces" */
 	for (y = 0; y < ysize - 1; y++)
 	  {
 	     for (x = 0; x < xsize - 1; x++)
 	       {
-/* if the square is empty "grow" the space */
+		  /* if the square is empty "grow" the space */
 		  if (!filled[(y * (xsize - 1)) + x])
 		    {
 		       int                 can_expand_x = 1;
@@ -504,7 +592,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		    }
 	       }
 	  }
-/* find the first space that fits */
+	/* find the first space that fits */
 	k = -1;
 	sort = 0x7fffffff;
 	a1 = floating[leftover[i]].w * floating[leftover[i]].h;
@@ -518,7 +606,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		  sort = a1 - a2;
 	       }
 	  }
-/* if there's a small space ... */
+	/* if there's a small space ... */
 	if (k >= 0)
 	  {
 	     sorted[num_sorted].x = spaces[k].x;
@@ -536,9 +624,10 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		sorted[num_sorted].y = starty;
 	     num_sorted++;
 	  }
-/* there is no room - put it centered (but dont put top left off screen) */
 	else
 	  {
+	     /* there is no room - put it centered */
+	     /* (but dont put top left off screen) */
 	     sorted[num_sorted].data = floating[leftover[i]].data;
 	     sorted[num_sorted].x = (width - floating[leftover[i]].w) / 2;
 	     sorted[num_sorted].y = (height - floating[leftover[i]].h) / 2;
@@ -551,7 +640,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     num_sorted++;
 	  }
      }
-/* free up memory */
+   /* free up memory */
    Efree(xarray);
    Efree(yarray);
    Efree(filled);
@@ -579,6 +668,13 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
    int                 gnum, num, i, j, screen_snap_dist, odx, ody;
    static char         last_res = 0;
 
+#ifdef HAS_XINERAMA
+   static XineramaScreenInfo *screens = NULL;
+
+#endif
+   static int          num_screens = 0;
+   int                 top_bound, bottom_bound, left_bound, right_bound;
+
    EDBUG(5, "SnapEwin");
    if (!ewin)
       EDBUG_RETURN_;
@@ -589,8 +685,51 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	*new_dy = dy;
 	EDBUG_RETURN_;
      }
+
+   left_bound = 0;
+   right_bound = root.w;
+   top_bound = 0;
+   bottom_bound = root.h;
+
    screen_snap_dist = mode.constrained ? (root.w + root.h)
       : mode.screen_snap_dist;
+
+#ifdef HAS_XINERAMA
+
+   if (xinerama_active)
+     {
+	if (!screens)
+	   screens = XineramaQueryScreens(disp, &num_screens);
+	for (i = 0; i < num_screens; i++)
+	  {
+	     if (ewin->x >= screens[i].x_org)
+	       {
+		  if (ewin->x <= (screens[i].width + screens[i].x_org))
+		    {
+		       if (ewin->y >= screens[i].y_org)
+			 {
+			    if (ewin->y <=
+				(screens[i].height + screens[i].y_org))
+			      {
+				 left_bound = screens[i].x_org;
+				 right_bound =
+				    screens[i].x_org + screens[i].width;
+				 top_bound = screens[i].y_org;
+				 bottom_bound =
+				    screens[i].y_org + screens[i].height;
+				 screen_snap_dist =
+				    mode.constrained ? (screens[i].width +
+							screens[i].height) :
+				    mode.screen_snap_dist;
+			      }
+			 }
+		    }
+	       }
+
+	  }
+     }
+#endif
+
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
    gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup, &gnum);
    if (gwins)
@@ -609,9 +748,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
    ody = dy;
    if (dx < 0)
      {
-	if (IN_BELOW(ewin->x + dx, 0, screen_snap_dist)
-	    && (ewin->x >= 0))
-	   dx = 0 - ewin->x;
+	if (IN_BELOW(ewin->x + dx, left_bound, screen_snap_dist)
+	    && (ewin->x >= left_bound))
+	  {
+	     dx = left_bound - ewin->x;
+	  }
 	else if (lst)
 	  {
 	     for (i = 0; i < num; i++)
@@ -621,12 +762,13 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 		       if (((ewin->desktop == lst[i]->desktop) ||
 			    (lst[i]->sticky)) &&
 			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) &&
-			   (!(lst[i]->ignorearrange)))
+			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
 			 {
-			    if (IN_BELOW(ewin->x + dx, lst[i]->x + lst[i]->w - 1,
-					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h)
+			    if (IN_BELOW
+				(ewin->x + dx, lst[i]->x + lst[i]->w - 1,
+				 mode.edge_snap_dist)
+				&& SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
+						lst[i]->h)
 				&& (ewin->x >= (lst[i]->x + lst[i]->w)))
 			      {
 				 dx = (lst[i]->x + lst[i]->w) - ewin->x;
@@ -641,9 +783,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
      }
    else if (dx > 0)
      {
-	if (IN_ABOVE(ewin->x + ewin->w + dx, root.w, screen_snap_dist)
-	    && ((ewin->x + ewin->w) <= root.w))
-	   dx = root.w - (ewin->x + ewin->w);
+	if (IN_ABOVE(ewin->x + ewin->w + dx, right_bound, screen_snap_dist)
+	    && ((ewin->x + ewin->w) <= right_bound))
+	  {
+	     dx = right_bound - (ewin->x + ewin->w);
+	  }
 	else if (lst)
 	  {
 	     for (i = 0; i < num; i++)
@@ -653,12 +797,12 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 		       if (((ewin->desktop == lst[i]->desktop) ||
 			    (lst[i]->sticky)) &&
 			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) &&
-			   (!(lst[i]->ignorearrange)))
+			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
 			 {
 			    if (IN_ABOVE(ewin->x + ewin->w + dx - 1, lst[i]->x,
 					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h)
+				SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
+					     lst[i]->h)
 				&& ((ewin->x + ewin->w) <= lst[i]->x))
 			      {
 				 dx = lst[i]->x - (ewin->x + ewin->w);
@@ -673,9 +817,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
      }
    if (dy < 0)
      {
-	if (IN_BELOW(ewin->y + dy, 0, screen_snap_dist)
-	    && (ewin->y >= 0))
-	   dy = 0 - ewin->y;
+	if (IN_BELOW(ewin->y + dy, top_bound, screen_snap_dist)
+	    && (ewin->y >= top_bound))
+	  {
+	     dy = top_bound - ewin->y;
+	  }
 	else if (lst)
 	  {
 	     for (i = 0; i < num; i++)
@@ -685,12 +831,13 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 		       if (((ewin->desktop == lst[i]->desktop) ||
 			    (lst[i]->sticky)) &&
 			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) &&
-			   (!(lst[i]->ignorearrange)))
+			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
 			 {
-			    if (IN_BELOW(ewin->y + dy, lst[i]->y + lst[i]->h - 1,
-					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w)
+			    if (IN_BELOW
+				(ewin->y + dy, lst[i]->y + lst[i]->h - 1,
+				 mode.edge_snap_dist)
+				&& SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+						lst[i]->w)
 				&& (ewin->y >= (lst[i]->y + lst[i]->h)))
 			      {
 				 dy = (lst[i]->y + lst[i]->h) - ewin->y;
@@ -705,9 +852,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
      }
    else if (dy > 0)
      {
-	if (IN_ABOVE(ewin->y + ewin->h + dy, root.h, screen_snap_dist)
-	    && ((ewin->y + ewin->h) <= root.h))
-	   dy = root.h - (ewin->y + ewin->h);
+	if (IN_ABOVE(ewin->y + ewin->h + dy, bottom_bound, screen_snap_dist)
+	    && ((ewin->y + ewin->h) <= bottom_bound))
+	  {
+	     dy = bottom_bound - (ewin->y + ewin->h);
+	  }
 	else if (lst)
 	  {
 	     for (i = 0; i < num; i++)
@@ -717,12 +866,12 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 		       if (((ewin->desktop == lst[i]->desktop) ||
 			    (lst[i]->sticky)) &&
 			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) &&
-			   (!(lst[i]->ignorearrange)))
+			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
 			 {
 			    if (IN_ABOVE(ewin->y + ewin->h + dy - 1, lst[i]->y,
 					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w)
+				SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+					     lst[i]->w)
 				&& ((ewin->y + ewin->h) <= lst[i]->y))
 			      {
 				 dy = lst[i]->y - (ewin->y + ewin->h);
@@ -741,12 +890,14 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
      {
 	if (!last_res)
 	  {
-/*           AUDIO_PLAY("SOUND_MOVE_RESIST"); */
+	     /* AUDIO_PLAY("SOUND_MOVE_RESIST"); */
 	     last_res = 1;
 	  }
      }
    else
-      last_res = 0;
+     {
+	last_res = 0;
+     }
    *new_dx = dx;
    *new_dy = dy;
    EDBUG_RETURN_;
@@ -773,10 +924,10 @@ ArrangeEwin(EWin * ewin)
 	  {
 	     if ((lst[i] != ewin) && (!lst[i]->iconified) &&
 		 (!lst[i]->ignorearrange) && (lst[i]->layer != 0) &&
-	     (((lst[i]->area_x == desks.desk[ewin->desktop].current_area_x) &&
-	       (lst[i]->area_y == desks.desk[ewin->desktop].current_area_y) &&
-	       (lst[i]->desktop == ewin->desktop)) ||
-	      (lst[i]->sticky)))
+		 (((lst[i]->area_x == desks.desk[ewin->desktop].current_area_x)
+		   && (lst[i]->area_y ==
+		       desks.desk[ewin->desktop].current_area_y)
+		   && (lst[i]->desktop == ewin->desktop)) || (lst[i]->sticky)))
 	       {
 		  fixed[j].data = lst[i];
 		  fixed[j].x = (lst[i])->x;
@@ -800,9 +951,13 @@ ArrangeEwin(EWin * ewin)
 		  if ((fixed[j].w > 0) && (fixed[j].h > 0))
 		    {
 		       if (!(lst[i])->never_use_area)
-			  fixed[j].p = (lst[i])->layer;
+			 {
+			    fixed[j].p = (lst[i])->layer;
+			 }
 		       else
-			  fixed[j].p = 50;
+			 {
+			    fixed[j].p = 50;
+			 }
 		       j++;
 		    }
 	       }
@@ -840,9 +995,13 @@ ArrangeEwin(EWin * ewin)
 		       if ((fixed[j].w > 0) && (fixed[j].h > 0))
 			 {
 			    if (blst[i]->sticky)
-			       fixed[j].p = 50;
+			      {
+				 fixed[j].p = 50;
+			      }
 			    else
-			       fixed[j].p = 0;
+			      {
+				 fixed[j].p = 0;
+			      }
 			    j++;
 			 }
 		    }
@@ -858,12 +1017,12 @@ ArrangeEwin(EWin * ewin)
 	if (mode.kde_support)
 	  {
 	     ArrangeRects(fixed, j, &newrect, 1, ret, mode.kde_x1, mode.kde_y1,
-			  mode.kde_x2, mode.kde_y2, ARRANGE_BY_SIZE);
+			  mode.kde_x2, mode.kde_y2, ARRANGE_BY_SIZE, 1);
 	  }
 	else
 	  {
 	     ArrangeRects(fixed, j, &newrect, 1, ret, 0, 0, root.w, root.h,
-			  ARRANGE_BY_SIZE);
+			  ARRANGE_BY_SIZE, 1);
 	  }
 	for (i = 0; i < j + 1; i++)
 	  {
@@ -882,8 +1041,51 @@ ArrangeEwin(EWin * ewin)
      }
    else
      {
-	ewin->x = (root.w - ewin->w) >> 1;
-	ewin->y = (root.h - ewin->h) >> 1;
+#ifdef HAS_XINERAMA
+	if (xinerama_active)
+	  {
+	     Window              rt, ch;
+	     XineramaScreenInfo *screens;
+	     int                 pointer_x, pointer_y;
+	     int                 num;
+	     int                 d;
+	     unsigned int        ud;
+
+	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y,
+			   &d, &d, &ud);
+	     screens = XineramaQueryScreens(disp, &num);
+	     for (i = 0; i < num; i++)
+	       {
+		  if (pointer_x >= screens[i].x_org)
+		    {
+		       if (pointer_x <= (screens[i].width + screens[i].x_org))
+			 {
+			    if (pointer_y >= screens[i].y_org)
+			      {
+				 if (pointer_y <= (screens[i].height +
+						   screens[i].y_org))
+				   {
+				      ewin->x =
+					 ((screens[i].width - ewin->w) /
+					  2) + screens[i].x_org;
+				      ewin->y =
+					 ((screens[i].height - ewin->h) /
+					  2) + screens[i].y_org;
+				   }
+			      }
+			 }
+		    }
+	       }
+	     XFree(screens);
+	  }
+	else
+	  {
+#endif
+	     ewin->x = (root.w - ewin->w) >> 1;
+	     ewin->y = (root.h - ewin->h) >> 1;
+#ifdef HAS_XINERAMA
+	  }
+#endif
      }
    MoveEwin(ewin, ewin->x, ewin->y);
 }
