@@ -1,19 +1,19 @@
 
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -109,11 +109,18 @@
 #define CONTROL_PAGER_SNAP 349
 #define CONTROL_ANIMATESHADING 350
 #define CONTROL_MENUONSCREEN 351
+#define CONTROL_AREA_WRAPAROUND 352
+#define CONTROL_DIALOG_HEADERS 353
+#define CONTROL_WARPMENUS 666
 #define CONTROL_USER_BG 1350
 #define CONTROL_PAGER_ZOOM 1351
 #define CONTROL_PAGER_TITLE 1352
 #define CONTROL_RAISE_AFTER_NEXT_FOCUS 1353
 #define CONTROL_DISPLAY_WARP 1354
+#define CONTROL_WARPSTICKY 667
+#define CONTROL_WARPSHADED 668
+#define CONTROL_WARPICONIFIED 669
+#define CONTROL_WARPFOCUSED 670
 #define CONTROL_WARP_AFTER_NEXT_FOCUS 1355
 #define CONTROL_PAGER_SCANSPEED 1356
 #define CONTROL_ICONTEXT 1357
@@ -128,6 +135,7 @@
 #define CONTROL_KDESUPPORT 1366
 #define CONTROL_CLICK_ALWAYS 1367
 #define CONTROL_SHOWROOTTOOLTIP 1368
+#define CONTROL_PAGER_BUTTONS 1369
 
 #define ICLASS_NAME 350
 #define ICLASS_NORMAL 351
