@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -68,8 +68,12 @@ SetCoords(int x, int y, int w, int h)
 	       case 0:
 	       case 1:
 	       case 2:
-		  cx = ewin->x + ((ewin->w - cw) / 2) + desks.desk[ewin->desktop].x;
-		  cy = ewin->y + ((ewin->h - ch) / 2) + desks.desk[ewin->desktop].y;
+		  cx =
+		     ewin->x + ((ewin->w - cw) / 2) +
+		     desks.desk[ewin->desktop].x;
+		  cy =
+		     ewin->y + ((ewin->h - ch) / 2) +
+		     desks.desk[ewin->desktop].y;
 		  break;
 	       case 3:
 		  cx = 0;
