@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -29,8 +29,7 @@
 char                throw_move_events_away = 0;
 void                DeskAccountTimeout(int val, void *data);
 
-HandleStruct        HArray[] =
-{
+HandleStruct        HArray[] = {
    {DefaultFunc},
    {DefaultFunc},
    {HKeyPress},
@@ -277,7 +276,8 @@ HandleEvent(XEvent * ev)
 	if (((ev->type == KeyPress) || (ev->type == KeyRelease)) &&
 	    (ev->xkey.root != root.win))
 	  {
-	     XSetInputFocus(disp, ev->xkey.root, RevertToPointerRoot, CurrentTime);
+	     XSetInputFocus(disp, ev->xkey.root, RevertToPointerRoot,
+			    CurrentTime);
 	     XSync(disp, False);
 	     ev->xkey.time = CurrentTime;
 	     XSendEvent(disp, ev->xkey.root, False, 0, ev);
@@ -346,8 +346,7 @@ WaitEvent()
 /*  XEvent              ev; */
    fd_set              fdset;
    struct timeval      tval;
-   static struct timeval tval_last =
-   {0, 0};
+   static struct timeval tval_last = { 0, 0 };
    double              time1, time2;
    Qentry             *qe;
    int                 count, pcount;
@@ -661,8 +660,7 @@ HLeaveNotify(XEvent * ev)
 	if (ev->xcrossing.window == root.win)
 	  {
 	     if (ev->xcrossing.mode == NotifyNormal &&
-		 ev->xcrossing.detail != NotifyInferior &&
-		 mode.focuswin)
+		 ev->xcrossing.detail != NotifyInferior && mode.focuswin)
 		HandleFocusWindow(root.focuswin);
 	     else
 		HandleFocusWindow(ev->xcrossing.window);
