@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -54,7 +54,7 @@ Etmp(char *s)
       n_calls = (unsigned long)time(NULL) + (unsigned long)getpid();
    Esnprintf(s, 1024, "%s/TMP_%Xl", UserEDir(), n_calls);
    n_calls++;
-   EDBUG_RETURN_
+   EDBUG_RETURN_;
 }
 
 void
@@ -762,8 +762,7 @@ field(char *s, int field)
    fword(s, field + 1, buf);
    if (buf[0])
      {
-	if ((!strcmp(buf, "NULL")) ||
-	    (!strcmp(buf, "(null)")))
+	if ((!strcmp(buf, "NULL")) || (!strcmp(buf, "(null)")))
 	   EDBUG_RETURN(NULL);
 	EDBUG_RETURN(duplicate(buf));
      }
@@ -780,8 +779,7 @@ fillfield(char *s, int field, char *buf)
    fword(s, field + 1, buf);
    if (buf[0])
      {
-	if ((!strcmp(buf, "NULL")) ||
-	    (!strcmp(buf, "(null)")))
+	if ((!strcmp(buf, "NULL")) || (!strcmp(buf, "(null)")))
 	  {
 	     buf[0] = 0;
 	     EDBUG_RETURN(0);
@@ -1082,3 +1080,42 @@ pathtofile(char *file)
 #endif
    EDBUG_RETURN(NULL);
 }
+
+int
+findLocalizedFile(char *fname)
+{
+#ifndef __EMX__
+   char               *tmp, *lang, *p[3];
+   int                 i;
+
+   if (!(lang = setlocale(LC_MESSAGES, NULL)))
+      return 0;
+
+   tmp = strdup(fname);
+   lang = strdup(lang);		/* lang may be in static space, thus it must
+				 * be duplicated before we change it below */
+   p[0] = lang + strlen(lang);
+   p[1] = strchr(lang, '.');
+   p[2] = strchr(lang, '_');
+
+   for (i = 0; i < 3; i++)
+     {
+	if (p[i] == NULL)
+	   continue;
+
+	*p[i] = '\0';
+	sprintf(fname, "%s.%s", tmp, lang);
+	if (isfile(fname))
+	  {
+	     free(tmp);
+	     free(lang);
+	     return 1;
+	  }
+     }
+   strcpy(fname, tmp);
+   free(tmp);
+   free(lang);
+#endif
+
+   return 0;
+}
