@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -74,10 +74,10 @@ GetNextFocusEwin(void)
 	     ewin = lst0[i];
 	     if (((ewin->sticky) || (ewin->desktop == desks.current)) &&
 		 ((ewin->area_x == ax) && (ewin->area_y == ay)) &&
-		 (!ewin->skipfocus) && (!ewin->shaded) &&
-		 (!ewin->menu) && (!ewin->pager) && (!ewin->ibox) &&
-		 (!ewin->iconified)	/*&& (ewin->client.mwm_decor_title) &&
-					 * (ewin->client.mwm_decor_border) */ )
+		 (!ewin->skipfocus) && (!ewin->neverfocus) && (!ewin->iconified)
+		 && (!ewin->menu) && (!ewin->pager) && (!ewin->ibox) && (!ewin->iconified)	/*&& (ewin->client.mwm_decor_title) &&
+												 * (ewin->client.mwm_decor_border) */
+		)
 	       {
 		  num++;
 		  lst = Erealloc(lst, sizeof(EWin *) * num);
@@ -145,10 +145,12 @@ GetPrevFocusEwin(void)
 	     DetermineEwinArea(ewin);
 	     if (((ewin->sticky) || (ewin->desktop == desks.current)) &&
 		 ((ewin->area_x == ax) && (ewin->area_y == ay)) &&
-		 (!ewin->skipfocus) && (!ewin->shaded) &&
-		 (!ewin->menu) && (!ewin->pager) && (!ewin->ibox) &&
-		 (!ewin->iconified)	/*&& (ewin->client.mwm_decor_title) &&
-					 * (ewin->client.mwm_decor_border) */ )
+		 (!ewin->skipfocus) && (!ewin->neverfocus) &&
+		 (!ewin->shaded) && (!ewin->menu) && (!ewin->pager) &&
+		 (!ewin->ibox) && (!ewin->iconified)
+		 /* && (ewin->client.mwm_decor_title) &&
+		  *    (ewin->client.mwm_decor_border) */
+		)
 	       {
 		  num++;
 		  lst = Erealloc(lst, sizeof(EWin *) * num);
@@ -207,13 +209,14 @@ FixFocus(void)
 	     if (mode.focusmode == FOCUS_CLICK)
 	       {
 		  if (!(ewin->active))
-		     XGrabButton(disp, AnyButton, AnyModifier, ewin->win_container,
-				 False, ButtonPressMask,
+		     XGrabButton(disp, AnyButton, AnyModifier,
+				 ewin->win_container, False, ButtonPressMask,
 				 GrabModeSync, GrabModeAsync, None, None);
 	       }
 	     else
 	       {
-		  XUngrabButton(disp, AnyButton, AnyModifier, ewin->win_container);
+		  XUngrabButton(disp, AnyButton, AnyModifier,
+				ewin->win_container);
 		  GrabButtonGrabs(ewin);
 	       }
 	  }
@@ -263,6 +266,11 @@ FocusToEWin(EWin * ewin)
    /* Never focus a window that's not on the current desktop.  That's just dumb. -- mej */
    if ((ewin) && (ewin->desktop != desks.current && !(ewin->sticky)))
       ewin = NULL;
+   /* addition by tom */
+   if ((ewin) && (ewin->neverfocus))
+     {
+	EDBUG_RETURN_;
+     }
    if ((ewin) && (!ewin->client.need_input))
      {
 	if (mode.windowdestroy == 1)
@@ -345,7 +353,8 @@ FocusToEWin(EWin * ewin)
 		  if ((ax != ewin->area_x) || (ay != ewin->area_y))
 		    {
 		       if ((ewin->x >= root.w) || (ewin->y >= root.h) ||
-		       ((ewin->x + ewin->w) < 0) || ((ewin->y + ewin->h) < 0))
+			   ((ewin->x + ewin->w) < 0)
+			   || ((ewin->y + ewin->h) < 0))
 			  SetCurrentArea(ewin->area_x, ewin->area_y);
 		    }
 	       }
@@ -379,8 +388,7 @@ BeginNewDeskFocus(void)
 			  FocusChangeMask |
 			  SubstructureNotifyMask |
 			  SubstructureRedirectMask |
-			  PropertyChangeMask |
-			  ResizeRedirectMask);
+			  PropertyChangeMask | ResizeRedirectMask);
 	     if (ewin->pager)
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
@@ -389,35 +397,29 @@ BeginNewDeskFocus(void)
 			     StructureNotifyMask |
 			     ColormapChangeMask |
 			     ButtonPressMask |
-			     ButtonReleaseMask |
-			     PointerMotionMask);
+			     ButtonReleaseMask | PointerMotionMask);
 	     else if (ewin->dialog)
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
 			     FocusChangeMask |
 			     ResizeRedirectMask |
 			     StructureNotifyMask |
-			     ColormapChangeMask |
-			     ExposureMask |
-			     KeyPressMask);
+			     ColormapChangeMask | ExposureMask | KeyPressMask);
 	     else
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
 			     FocusChangeMask |
 			     ResizeRedirectMask |
-			     StructureNotifyMask |
-			     ColormapChangeMask);
+			     StructureNotifyMask | ColormapChangeMask);
 	     for (j = 0; j < ewin->border->num_winparts; j++)
 	       {
 		  if (ewin->border->part[j].flags & FLAG_TITLE)
 		     XSelectInput(disp, ewin->bits[j].win,
 				  ExposureMask |
-				  ButtonPressMask |
-				  ButtonReleaseMask);
+				  ButtonPressMask | ButtonReleaseMask);
 		  else
 		     XSelectInput(disp, ewin->bits[j].win,
-				  ButtonPressMask |
-				  ButtonReleaseMask);
+				  ButtonPressMask | ButtonReleaseMask);
 	       }
 	  }
 	Efree(lst);
@@ -426,8 +428,7 @@ BeginNewDeskFocus(void)
       XSelectInput(disp, desks.desk[i].win,
 		   PropertyChangeMask |
 		   SubstructureRedirectMask |
-		   ButtonPressMask |
-		   ButtonReleaseMask);
+		   ButtonPressMask | ButtonReleaseMask);
 }
 
 void
@@ -454,8 +455,7 @@ NewDeskFocus(void)
 			  PointerMotionMask |
 			  PropertyChangeMask |
 			  ResizeRedirectMask |
-			  ButtonPressMask |
-			  ButtonReleaseMask);
+			  ButtonPressMask | ButtonReleaseMask);
 	     if (ewin->pager)
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
@@ -466,8 +466,7 @@ NewDeskFocus(void)
 			     StructureNotifyMask |
 			     ColormapChangeMask |
 			     ButtonPressMask |
-			     ButtonReleaseMask |
-			     PointerMotionMask);
+			     ButtonReleaseMask | PointerMotionMask);
 	     else if (ewin->dialog)
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
@@ -476,9 +475,7 @@ NewDeskFocus(void)
 			     FocusChangeMask |
 			     ResizeRedirectMask |
 			     StructureNotifyMask |
-			     ColormapChangeMask |
-			     ExposureMask |
-			     KeyPressMask);
+			     ColormapChangeMask | ExposureMask | KeyPressMask);
 	     else
 		XSelectInput(disp, ewin->client.win,
 			     PropertyChangeMask |
@@ -486,8 +483,7 @@ NewDeskFocus(void)
 			     LeaveWindowMask |
 			     FocusChangeMask |
 			     ResizeRedirectMask |
-			     StructureNotifyMask |
-			     ColormapChangeMask);
+			     StructureNotifyMask | ColormapChangeMask);
 	     for (j = 0; j < ewin->border->num_winparts; j++)
 	       {
 		  if (ewin->border->part[j].flags & FLAG_TITLE)
@@ -498,8 +494,7 @@ NewDeskFocus(void)
 				  ButtonPressMask |
 				  ButtonReleaseMask |
 				  EnterWindowMask |
-				  LeaveWindowMask |
-				  PointerMotionMask);
+				  LeaveWindowMask | PointerMotionMask);
 		  else
 		     XSelectInput(disp, ewin->bits[j].win,
 				  KeyPressMask |
@@ -507,8 +502,7 @@ NewDeskFocus(void)
 				  ButtonPressMask |
 				  ButtonReleaseMask |
 				  EnterWindowMask |
-				  LeaveWindowMask |
-				  PointerMotionMask);
+				  LeaveWindowMask | PointerMotionMask);
 	       }
 	  }
 	Efree(lst);
@@ -523,11 +517,8 @@ NewDeskFocus(void)
 		   ButtonMotionMask |
 		   PropertyChangeMask |
 		   SubstructureRedirectMask |
-		   KeyPressMask |
-		   KeyReleaseMask |
-		   PointerMotionMask);
-   if ((mode.focusmode == FOCUS_POINTER) ||
-       (mode.focusmode == FOCUS_SLOPPY))
+		   KeyPressMask | KeyReleaseMask | PointerMotionMask);
+   if ((mode.focusmode == FOCUS_POINTER) || (mode.focusmode == FOCUS_SLOPPY))
      {
 	ewin = GetEwinPointerInClient();
 	if (ewin)
