@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -54,14 +54,20 @@ ICCCM_GetTitle(EWin * ewin, Atom atom_change)
 		  XFreeStringList(list);
 	       }
 	     else
-		ewin->client.title = duplicate((char *)xtp.value);
+	       {
+		  ewin->client.title = duplicate((char *)xtp.value);
+	       }
 	  }
 	else
-	   ewin->client.title = duplicate((char *)xtp.value);
+	  {
+	     ewin->client.title = duplicate((char *)xtp.value);
+	  }
 	XFree(xtp.value);
      }
    else if (!ewin->internal)
-      ewin->client.title = duplicate("No Title");
+     {
+	ewin->client.title = duplicate("No Title");
+     }
    EDBUG_RETURN_;
 }
 
@@ -88,12 +94,18 @@ ICCCM_GetColormap(EWin * ewin)
    if (XGetWindowAttributes(disp, ewin->client.win, &xwa))
      {
 	if (xwa.colormap)
-	   ewin->client.cmap = xwa.colormap;
+	  {
+	     ewin->client.cmap = xwa.colormap;
+	  }
 	else
-	   ewin->client.cmap = 0;
+	  {
+	     ewin->client.cmap = 0;
+	  }
      }
    else
-      ewin->client.cmap = 0;
+     {
+	ewin->client.cmap = 0;
+     }
    EDBUG_RETURN_;
 }
 
@@ -139,8 +151,8 @@ ICCCM_Delete(EWin * ewin)
    del = 0;
    if (!XGetWMProtocols(disp, ewin->client.win, &prop, &num))
      {
-	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False, a2, &a3, &dummy,
-			   &lnum, &ldummy, (unsigned char **)&prop);
+	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False, a2, &a3,
+			   &dummy, &lnum, &ldummy, (unsigned char **)&prop);
 	num = (int)lnum;
      }
    if (prop)
@@ -161,7 +173,9 @@ ICCCM_Delete(EWin * ewin)
 	XSendEvent(disp, ewin->client.win, False, 0, (XEvent *) & ev);
      }
    else
-      XKillClient(disp, (XID) ewin->client.win);
+     {
+	XKillClient(disp, (XID) ewin->client.win);
+     }
    EDBUG_RETURN_;
 }
 
@@ -226,8 +240,7 @@ ICCCM_DeIconify(EWin * ewin)
    ewin->iconified = 0;
    XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace,
 		   (unsigned char *)c, 2);
-   RemoveItem("ICON", ewin->client.win, LIST_FINDBY_BOTH,
-	      LIST_TYPE_ICONIFIEDS);
+   RemoveItem("ICON", ewin->client.win, LIST_FINDBY_BOTH, LIST_TYPE_ICONIFIEDS);
    EMapWindow(disp, ewin->client.win);
    EDBUG_RETURN_;
 }
@@ -309,7 +322,8 @@ ICCCM_Configure(EWin * ewin)
 	xwc.y = ewin->border->border.top;
 	xwc.width = ewin->client.w;
 	xwc.height = ewin->client.h;
-	XConfigureWindow(disp, ewin->win_container, CWX | CWY | CWWidth | CWHeight, &xwc);
+	XConfigureWindow(disp, ewin->win_container,
+			 CWX | CWY | CWWidth | CWHeight, &xwc);
      }
    else
      {
@@ -317,13 +331,15 @@ ICCCM_Configure(EWin * ewin)
 	xwc.y = -30;
 	xwc.width = 1;
 	xwc.height = 1;
-	XConfigureWindow(disp, ewin->win_container, CWX | CWY | CWWidth | CWHeight, &xwc);
+	XConfigureWindow(disp, ewin->win_container,
+			 CWX | CWY | CWWidth | CWHeight, &xwc);
 	xwc.width = ewin->client.w;
 	xwc.height = ewin->client.h;
      }
    xwc.x = 0;
    xwc.y = 0;
-   XConfigureWindow(disp, ewin->client.win, CWX | CWY | CWWidth | CWHeight, &xwc);
+   XConfigureWindow(disp, ewin->client.win, CWX | CWY | CWWidth | CWHeight,
+		    &xwc);
    if ((ewin->menu) || (ewin->dialog))
       EDBUG_RETURN_;
    ev.type = ConfigureNotify;
@@ -373,17 +389,23 @@ ICCCM_Adopt(EWin * ewin, Window win)
    if (!a)
       a = XInternAtom(disp, "WM_STATE", False);
    if (ewin->client.start_iconified)
-      c[0] = IconicState;
+     {
+	c[0] = IconicState;
+     }
    else
-      c[0] = NormalState;
+     {
+	c[0] = NormalState;
+     }
    c[1] = 0;
    XChangeProperty(disp, win, a, a, 32, PropModeReplace, (unsigned char *)c, 2);
    ewin->x = ewin->client.x;
    ewin->y = ewin->client.y;
    ewin->reqx = ewin->client.x;
    ewin->reqy = ewin->client.y;
-   ewin->w = ewin->client.w + ewin->border->border.left + ewin->border->border.right;
-   ewin->h = ewin->client.h + ewin->border->border.top + ewin->border->border.bottom;
+   ewin->w =
+      ewin->client.w + ewin->border->border.left + ewin->border->border.right;
+   ewin->h =
+      ewin->client.h + ewin->border->border.top + ewin->border->border.bottom;
    EDBUG_RETURN_;
 }
 
@@ -405,7 +427,8 @@ ICCCM_Withdraw(EWin * ewin)
     */
    c[0] = WithdrawnState;
    c[1] = 0;
-   XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace, (unsigned char *)c, 2);
+   XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace,
+		   (unsigned char *)c, 2);
    EDBUG_RETURN_;
 }
 
@@ -495,8 +518,8 @@ ICCCM_Focus(EWin * ewin)
      }
    if (!XGetWMProtocols(disp, ewin->client.win, &prop, &num))
      {
-	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False, a2, &a3, &dummy,
-			   &lnum, &ldummy, (unsigned char **)&prop);
+	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False, a2, &a3,
+			   &dummy, &lnum, &ldummy, (unsigned char **)&prop);
 	num = (int)lnum;
      }
    if (prop)
@@ -527,7 +550,7 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
    XSizeHints          hint;
    Window              ww;
    long                mask;
-   unsigned int        dummy, w, h;
+   unsigned int        dummy, w, h, bw;
    int                 x, y;
 
    EDBUG(6, "ICCCM_GetGeoms");
@@ -540,22 +563,26 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	if (atom_change != atom)
 	   EDBUG_RETURN_;
      }
-   EGetGeometry(disp, ewin->client.win, &ww, &x, &y, &w, &h, &dummy, &dummy);
+   EGetGeometry(disp, ewin->client.win, &ww, &x, &y, &w, &h, &bw, &dummy);
    ewin->client.x = x;
    ewin->client.y = y;
    ewin->client.w = w;
    ewin->client.h = h;
+   ewin->client.bw = bw;
    if (XGetWMNormalHints(disp, ewin->client.win, &hint, &mask))
      {
 	if (!(ewin->client.already_placed))
 	  {
-	     if ((hint.flags & USPosition) ||
-		 ((hint.flags & PPosition)))
+	     if ((hint.flags & USPosition) || ((hint.flags & PPosition)))
 	       {
 		  if (hint.flags & PWinGravity)
-		     ewin->client.grav = hint.win_gravity;
+		    {
+		       ewin->client.grav = hint.win_gravity;
+		    }
 		  else
-		     ewin->client.grav = NorthWestGravity;
+		    {
+		       ewin->client.grav = NorthWestGravity;
+		    }
 		  ewin->client.x = x;
 		  ewin->client.y = y;
 		  if ((hint.flags & PPosition) && (!ewin->sticky))
@@ -568,13 +595,21 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 		       ewin->client.x -= desks.desk[dsk].x;
 		       ewin->client.y -= desks.desk[dsk].y;
 		       if (ewin->client.x + ewin->client.w >= root.w)
-			  ewin->client.x += desks.desk[dsk].x;
+			 {
+			    ewin->client.x += desks.desk[dsk].x;
+			 }
 		       else if (ewin->client.x < 0)
-			  ewin->client.x += desks.desk[dsk].x;
+			 {
+			    ewin->client.x += desks.desk[dsk].x;
+			 }
 		       if (ewin->client.y + ewin->client.h >= root.h)
-			  ewin->client.y += desks.desk[dsk].y;
+			 {
+			    ewin->client.y += desks.desk[dsk].y;
+			 }
 		       else if (ewin->client.y < 0)
-			  ewin->client.y += desks.desk[dsk].y;
+			 {
+			    ewin->client.y += desks.desk[dsk].y;
+			 }
 		    }
 		  ewin->client.already_placed = 1;
 	       }
@@ -631,14 +666,18 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 		     ((double)hint.min_aspect.y);
 	       }
 	     else
-		ewin->client.aspect_min = 0.0;
+	       {
+		  ewin->client.aspect_min = 0.0;
+	       }
 	     if ((hint.max_aspect.y > 0.0) && (hint.max_aspect.x > 0.0))
 	       {
 		  ewin->client.aspect_max = ((double)hint.max_aspect.x) /
 		     ((double)hint.max_aspect.y);
 	       }
 	     else
-		ewin->client.aspect_max = 65535.0;
+	       {
+		  ewin->client.aspect_max = 65535.0;
+	       }
 	  }
 	else
 	  {
@@ -647,11 +686,6 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	  }
 	if (hint.flags & PBaseSize)
 	  {
-	     if (!(hint.flags & PMaxSize))
-	       {
-		  ewin->client.width.min = hint.base_width;
-		  ewin->client.height.min = hint.base_height;
-	       }
 	     ewin->client.base_w = hint.base_width;
 	     ewin->client.base_h = hint.base_height;
 	  }
@@ -660,10 +694,14 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	     ewin->client.base_w = ewin->client.width.min;
 	     ewin->client.base_h = ewin->client.height.min;
 	  }
-	if (ewin->client.width.min < 1)
-	   ewin->client.width.min = 1;
-	if (ewin->client.height.min < 1)
-	   ewin->client.height.min = 1;
+	if (ewin->client.base_w < 1)
+	   ewin->client.base_w = 1;
+	if (ewin->client.base_h < 1)
+	   ewin->client.base_h = 1;
+	if (ewin->client.width.min < ewin->client.base_w)
+	   ewin->client.width.min = ewin->client.base_w;
+	if (ewin->client.height.min < ewin->client.base_h)
+	   ewin->client.height.min = ewin->client.base_h;
      }
    if (ewin->client.width.min == 0)
      {
@@ -769,7 +807,9 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 		  ewin->client.command = s;
 	       }
 	     else
-		ewin->client.command = NULL;
+	       {
+		  ewin->client.command = NULL;
+	       }
 	  }
 	else if (XGetCommand(disp, ewin->client.group, &cargv, &cargc))
 	  {
@@ -809,14 +849,20 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 		       ewin->client.command = s;
 		    }
 		  else
-		     ewin->client.command = NULL;
+		    {
+		       ewin->client.command = NULL;
+		    }
 		  XFreeStringList(cargv);
 	       }
 	     else
-		ewin->client.command = NULL;
+	       {
+		  ewin->client.command = NULL;
+	       }
 	  }
 	else
-	   ewin->client.command = NULL;
+	  {
+	     ewin->client.command = NULL;
+	  }
      }
    ok = 1;
    if (atom_change)
@@ -845,7 +891,9 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	     XFree(xtp.value);
 	  }
 	else
-	   ewin->client.machine = NULL;
+	  {
+	     ewin->client.machine = NULL;
+	  }
      }
    ok = 1;
    if (atom_change)
@@ -864,7 +912,9 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	     if (ewin->client.icon_name)
 		Efree(ewin->client.icon_name);
 	     if (xtp.encoding == XA_STRING)
-		ewin->client.icon_name = duplicate((char *)xtp.value);
+	       {
+		  ewin->client.icon_name = duplicate((char *)xtp.value);
+	       }
 	     else
 	       {
 		  char              **cl;
@@ -887,7 +937,9 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	     if (ewin->client.icon_name)
 		Efree(ewin->client.icon_name);
 	     if (xtp.encoding == XA_STRING)
-		ewin->client.icon_name = duplicate((char *)xtp.value);
+	       {
+		  ewin->client.icon_name = duplicate((char *)xtp.value);
+	       }
 	     else
 	       {
 		  char              **cl;
@@ -906,9 +958,10 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	     XFree(xtp.value);
 	  }
 	else
-	   ewin->client.icon_name = NULL;
+	  {
+	     ewin->client.icon_name = NULL;
+	  }
      }
-
    ok = 1;
    if (atom_change)
      {
@@ -941,6 +994,7 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
      }
    EDBUG_RETURN_;
 }
+
 void
 ICCCM_GetHints(EWin * ewin, Atom atom_change)
 {
@@ -972,7 +1026,8 @@ ICCCM_GetHints(EWin * ewin, Atom atom_change)
    if (hint)
      {
 	/* I have to make sure the thing i'm docking is a dock app */
-	if ((hint->flags & StateHint) && (hint->initial_state == WithdrawnState))
+	if ((hint->flags & StateHint)
+	    && (hint->initial_state == WithdrawnState))
 	  {
 	     if (hint->flags & (StateHint | IconWindowHint |
 				IconPositionHint | WindowGroupHint))
@@ -985,37 +1040,65 @@ ICCCM_GetHints(EWin * ewin, Atom atom_change)
 	if (hint->flags & InputHint)
 	  {
 	     if (hint->input)
-		ewin->client.need_input = 1;
+	       {
+		  ewin->client.need_input = 1;
+	       }
 	     else
-		ewin->client.need_input = 0;
+	       {
+		  ewin->client.need_input = 0;
+	       }
 	  }
 	else
-	   ewin->client.need_input = 1;
+	  {
+	     ewin->client.need_input = 1;
+	  }
 	if (hint->flags & StateHint)
 	  {
 	     if (hint->initial_state == IconicState)
-		ewin->client.start_iconified = 1;
+	       {
+		  ewin->client.start_iconified = 1;
+	       }
 	     else
-		ewin->client.start_iconified = 0;
+	       {
+		  ewin->client.start_iconified = 0;
+	       }
 	  }
 	else
-	   ewin->client.start_iconified = 0;
+	  {
+	     ewin->client.start_iconified = 0;
+	  }
 	if (hint->flags & IconPixmapHint)
-	   ewin->client.icon_pmap = hint->icon_pixmap;
+	  {
+	     ewin->client.icon_pmap = hint->icon_pixmap;
+	  }
 	else
-	   ewin->client.icon_pmap = 0;
+	  {
+	     ewin->client.icon_pmap = 0;
+	  }
 	if (hint->flags & IconMaskHint)
-	   ewin->client.icon_mask = hint->icon_mask;
+	  {
+	     ewin->client.icon_mask = hint->icon_mask;
+	  }
 	else
-	   ewin->client.icon_mask = 0;
+	  {
+	     ewin->client.icon_mask = 0;
+	  }
 	if (hint->flags & IconWindowHint)
-	   ewin->client.icon_win = hint->icon_window;
+	  {
+	     ewin->client.icon_win = hint->icon_window;
+	  }
 	else
-	   ewin->client.icon_win = 0;
+	  {
+	     ewin->client.icon_win = 0;
+	  }
 	if (hint->flags & WindowGroupHint)
-	   ewin->client.group = hint->window_group;
+	  {
+	     ewin->client.group = hint->window_group;
+	  }
 	else
-	   ewin->client.group = 0;
+	  {
+	     ewin->client.group = 0;
+	  }
 	XFree(hint);
      }
    ok = 1;
@@ -1053,11 +1136,17 @@ ICCCM_GetHints(EWin * ewin, Atom atom_change)
 	ewin->client.transient_for = w;
      }
    else
-      ewin->client.transient = 0;
+     {
+	ewin->client.transient = 0;
+     }
    if (ewin->client.group == ewin->client.win)
-      ewin->client.is_group_leader = 1;
+     {
+	ewin->client.is_group_leader = 1;
+     }
    else
-      ewin->client.is_group_leader = 0;
+     {
+	ewin->client.is_group_leader = 0;
+     }
    ok = 1;
    if (atom_change)
      {
@@ -1174,8 +1263,8 @@ ICCCM_SetEInfo(EWin * ewin)
    c[5] = ewin->shaded;
    c[6] = ewin->client.w;
    c[7] = ewin->client.h;
-   XChangeProperty(disp, ewin->client.win, a, XA_CARDINAL, 32, PropModeReplace,
-		   (unsigned char *)c, 9);
+   XChangeProperty(disp, ewin->client.win, a, XA_CARDINAL, 32,
+		   PropModeReplace, (unsigned char *)c, 9);
    XChangeProperty(disp, ewin->client.win, aa, XA_STRING, 8, PropModeReplace,
 		   (unsigned char *)ewin->border->name,
 		   strlen(ewin->border->name) + 1);
@@ -1283,8 +1372,9 @@ ICCCM_GetEInfo(EWin * ewin)
 		  ewin->client.w = c[6];
 		  ewin->client.h = c[7];
 	       }
-	     XGetWindowProperty(disp, ewin->client.win, aa, 0, 0xffff, True, XA_STRING,
-			 &a2, &dummy, &lnum, &ldummy, (unsigned char **)&str);
+	     XGetWindowProperty(disp, ewin->client.win, aa, 0, 0xffff, True,
+				XA_STRING, &a2, &dummy, &lnum, &ldummy,
+				(unsigned char **)&str);
 	     num = (int)lnum;
 
 	     if ((num > 0) && (str))
@@ -1292,8 +1382,7 @@ ICCCM_GetEInfo(EWin * ewin)
 		  Border             *b = NULL;
 
 		  b = (Border *) FindItem(str, 0,
-					  LIST_FINDBY_NAME,
-					  LIST_TYPE_BORDER);
+					  LIST_FINDBY_NAME, LIST_TYPE_BORDER);
 		  if ((ewin->border) && (strcmp(ewin->border->name, b->name)))
 		     b = NULL;
 		  if (b)
