@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -35,14 +35,13 @@ CreateIclass()
 
    i->name = NULL;
    i->external = 0;
-   i->norm.normal = i->norm.hilited = i->norm.clicked
-      = i->norm.disabled = NULL;
-   i->active.normal = i->active.hilited = i->active.clicked
-      = i->active.disabled = NULL;
-   i->sticky.normal = i->sticky.hilited = i->sticky.clicked
-      = i->sticky.disabled = NULL;
-   i->sticky_active.normal = i->sticky_active.hilited
-      = i->sticky_active.clicked = i->sticky_active.disabled = NULL;
+   i->norm.normal = i->norm.hilited = i->norm.clicked = i->norm.disabled = NULL;
+   i->active.normal = i->active.hilited = i->active.clicked =
+      i->active.disabled = NULL;
+   i->sticky.normal = i->sticky.hilited = i->sticky.clicked =
+      i->sticky.disabled = NULL;
+   i->sticky_active.normal = i->sticky_active.hilited =
+      i->sticky_active.clicked = i->sticky_active.disabled = NULL;
    i->padding.left = 0;
    i->padding.right = 0;
    i->padding.top = 0;
@@ -109,9 +108,9 @@ FreeImageClass(ImageClass * i)
      {
 	char                stuff[255];
 
-	Esnprintf(stuff, sizeof(stuff), "Error: %u references remain\n",
+	Esnprintf(stuff, sizeof(stuff), _("%u references remain\n"),
 		  i->ref_count);
-	DIALOG_OK("ImageClass Error", stuff);
+	DIALOG_OK(_("ImageClass Error!"), stuff);
 	EDBUG_RETURN_;
      }
    while (RemoveItemByPtr(i, LIST_TYPE_ICLASS));
@@ -727,8 +726,8 @@ IclassApply(ImageClass * iclass, Window win, int w, int h,
 				 gcv.ts_y_origin = 0;
 				 tm = ECreatePixmap(disp, win, w, h, 1);
 				 gc = XCreateGC(disp, tm, GCFillStyle | GCTile |
-					GCTileStipXOrigin | GCTileStipYOrigin,
-						&gcv);
+						GCTileStipXOrigin |
+						GCTileStipYOrigin, &gcv);
 				 XFillRectangle(disp, tm, gc, 0, 0, w, h);
 				 XFreeGC(disp, gc);
 				 EShapeCombineMask(disp, win, ShapeBounding,
@@ -1038,8 +1037,8 @@ IclassApplyCopy(ImageClass * iclass, Window win, int w, int h, int active,
 			    gcv.ts_x_origin = 0;
 			    gcv.ts_y_origin = 0;
 			    gc = XCreateGC(disp, tm, GCFillStyle | GCTile |
-					GCTileStipXOrigin | GCTileStipYOrigin,
-					   &gcv);
+					   GCTileStipXOrigin |
+					   GCTileStipYOrigin, &gcv);
 			    XFillRectangle(disp, tm, gc, 0, 0, w, h);
 			    XFreeGC(disp, gc);
 			 }
