@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -27,7 +27,8 @@ static MenuStyle   *desk_menu_style = NULL;
 static MenuStyle   *group_menu_style = NULL;
 
 static void         FileMenuUpdate(int val, void *data);
-static void         FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file, Menu * parent);
+static void         FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name,
+				     char *file, Menu * parent);
 
 void
 ShowTaskMenu(void)
@@ -271,8 +272,10 @@ void
 ShowMenu(Menu * m, char noshow)
 {
    EWin               *ewin;
-   int                 x, y, wx = 0, wy = 0;	/* wx, wy added to stop menus from appearing offscreen */
-   unsigned int        w, h, mw, mh;
+   int                 x, y;
+   int                 wx = 0, wy = 0;	/* wx, wy added to stop menus */
+   unsigned int        w, h, mw, mh;	/* from appearing offscreen */
+   int                 head_num = 0;
 
    EDBUG(5, "ShowMenu");
    if ((m->num <= 0) || (!m->style))
@@ -308,10 +311,10 @@ ShowMenu(Menu * m, char noshow)
    ewin = FindEwinByMenu(m);
    if (ewin)
      {
-	if ((mode.button) && FindItem((char *)mode.button, 0, LIST_FINDBY_POINTER,
-				      LIST_TYPE_BUTTON))
+	if ((mode.button)
+	    && FindItem((char *)mode.button, 0, LIST_FINDBY_POINTER,
+			LIST_TYPE_BUTTON))
 	  {
-	     fprintf(stderr, "setting back to normal\n");
 	     mode.button->state = STATE_NORMAL;
 	     DrawButton(mode.button);
 	  }
@@ -322,6 +325,15 @@ ShowMenu(Menu * m, char noshow)
    GetWinWH(m->items[0]->win, &w, &h);
    GetWinWH(m->win, &mw, &mh);
 
+   if (!mode.button)
+     {
+	int                 dum;
+	Window              rt, ch;
+
+	XQueryPointer(disp, m->win, &rt, &ch, &(mode.x), &(mode.y),
+		      &dum, &dum, (unsigned int *)&dum);
+     }
+
    wx = 0;
    wy = 0;
    if (mode.menusonscreen)
@@ -332,21 +344,73 @@ ShowMenu(Menu * m, char noshow)
 				LIST_TYPE_BORDER);
 	if (b)
 	  {
-	     if (mode.x - x - ((int)mw / 2) > (int)root.w)
-		wx = 0 + (int)b->border.left;
-	     else if (mode.x + ((int)mw / 2) > (int)root.w)
-		wx = root.w - (int)mw - (int)b->border.right;
+	     int                 width;
+	     int                 height;
+	     int                 x_origin;
+	     int                 y_origin;
+
+	     width = root.w;
+	     height = root.h;
+	     x_origin = 0;
+	     y_origin = 0;
+
+#ifdef HAS_XINERAMA
+	     if (xinerama_active)
+	       {
+		  Window              rt, ch;
+		  XineramaScreenInfo *screens;
+		  int                 pointer_x, pointer_y;
+		  int                 num;
+		  int                 d;
+		  unsigned int        ud;
+		  int                 i;
+
+		  XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
+				&pointer_y, &d, &d, &ud);
+		  screens = XineramaQueryScreens(disp, &num);
+		  for (i = 0; i < num; i++)
+		    {
+		       if (pointer_x >= screens[i].x_org)
+			 {
+			    if (pointer_x <=
+				(screens[i].width + screens[i].x_org))
+			      {
+				 if (pointer_y >= screens[i].y_org)
+				   {
+				      if (pointer_y <= (screens[i].height +
+							screens[i].y_org))
+					{
+					   x_origin = screens[i].x_org;
+					   y_origin = screens[i].y_org;
+					   width = screens[i].width;
+					   height = screens[i].height;
+					   head_num = i;
+					}
+				   }
+			      }
+			 }
+		    }
+		  XFree(screens);
+	       }
+#endif
+
+	     if (mode.x - x - ((int)mw / 2) > (x_origin + width))
+		wx = x_origin + (int)b->border.left;
+	     else if (mode.x + ((int)mw / 2) > (int)(x_origin + width))
+		wx = (x_origin + width) - (int)mw - (int)b->border.right;
 	     else
 		wx = mode.x - x - ((int)w / 2);
-	     if ((wx - ((int)w / 2)) < 0)
-		wx = (int)b->border.left;
+
+	     if ((wx - ((int)w / 2)) < x_origin)
+		wx = x_origin + (int)b->border.left;
 
 	     if (mode.y + (int)mh > (int)root.h)
-		wy = (int)root.h - (int)mh - (int)b->border.bottom;
+		wy = (y_origin + height) - (int)mh - (int)b->border.bottom;
 	     else
 		wy = mode.y - y - ((int)h / 2);
-	     if ((wy - ((int)h / 2) - (int)b->border.top) < 0)
-		wy = (int)b->border.top;
+
+	     if ((wy - ((int)h / 2) - (int)b->border.top) < y_origin)
+		wy = y_origin + (int)b->border.top;
 	  }
      }
 
@@ -355,7 +419,8 @@ ShowMenu(Menu * m, char noshow)
 	if (mode.menusonscreen)
 	   EMoveWindow(disp, m->win, wx, wy);
 	else
-	   EMoveWindow(disp, m->win, mode.x - x - (w / 2), mode.y - y - (h / 2));
+	   EMoveWindow(disp, m->win, mode.x - x - (w / 2),
+		       mode.y - y - (h / 2));
      }
    else if ((mode.x >= 0) && (mode.y < 0))
      {
@@ -388,6 +453,7 @@ ShowMenu(Menu * m, char noshow)
      {
 	DesktopRemoveEwin(ewin);
 	ewin->layer = 99;
+	ewin->head = head_num;
 	DesktopAddEwinToTop(ewin);
 	if (ewin->desktop != 0)
 	   MoveEwin(ewin, ewin->x - desks.desk[ewin->desktop].x,
@@ -670,8 +736,9 @@ AddTitleToMenu(Menu * menu, char *title)
 void
 RealizeMenu(Menu * m)
 {
-   int                 i, maxh = 0, maxw = 0, maxx1, maxx2, w, h, x, y, r,
-                       mmw, mmh;
+   int                 i, maxh = 0, maxw =
+
+      0, maxx1, maxx2, w, h, x, y, r, mmw, mmh;
    unsigned int        iw, ih;
    ImlibImage         *im;
    XSetWindowAttributes att;
@@ -728,7 +795,8 @@ RealizeMenu(Menu * m)
 							im->rgb_width,
 							im->rgb_height, 0);
 		  EMapWindow(disp, m->items[i]->icon_win);
-		  XChangeWindowAttributes(disp, m->items[i]->icon_win, CWEventMask, &att);
+		  XChangeWindowAttributes(disp, m->items[i]->icon_win,
+					  CWEventMask, &att);
 		  m->items[i]->icon_w = im->rgb_width;
 		  m->items[i]->icon_h = im->rgb_height;
 		  if (im->rgb_height > maxh)
@@ -743,20 +811,24 @@ RealizeMenu(Menu * m)
      }
    if (((has_i) && (has_s)) || ((!has_i) && (!has_s)))
      {
-	if (m->style->item_iclass->padding.top > m->style->sub_iclass->padding.top)
+	if (m->style->item_iclass->padding.top >
+	    m->style->sub_iclass->padding.top)
 	   maxh += m->style->item_iclass->padding.top;
 	else
 	   maxh += m->style->sub_iclass->padding.top;
-	if (m->style->item_iclass->padding.bottom > m->style->sub_iclass->padding.bottom)
+	if (m->style->item_iclass->padding.bottom >
+	    m->style->sub_iclass->padding.bottom)
 	   maxh += m->style->item_iclass->padding.bottom;
 	else
 	   maxh += m->style->sub_iclass->padding.bottom;
 	maxw = maxx1 + maxx2;
-	if (m->style->item_iclass->padding.left > m->style->sub_iclass->padding.left)
+	if (m->style->item_iclass->padding.left >
+	    m->style->sub_iclass->padding.left)
 	   maxw += m->style->item_iclass->padding.left;
 	else
 	   maxw += m->style->sub_iclass->padding.left;
-	if (m->style->item_iclass->padding.right > m->style->sub_iclass->padding.right)
+	if (m->style->item_iclass->padding.right >
+	    m->style->sub_iclass->padding.right)
 	   maxw += m->style->item_iclass->padding.right;
 	else
 	   maxw += m->style->sub_iclass->padding.right;
@@ -818,8 +890,8 @@ RealizeMenu(Menu * m)
 	     iw = 0;
 	     ih = 0;
 	     GetWinWH(m->items[i]->icon_win, &iw, &ih);
-	     IclassApply(m->items[i]->icon_iclass, m->items[i]->icon_win, iw, ih,
-			 0, 0, STATE_NORMAL, 0);
+	     IclassApply(m->items[i]->icon_iclass, m->items[i]->icon_win, iw,
+			 ih, 0, 0, STATE_NORMAL, 0);
 	  }
 	if (x + maxw > mmw)
 	   mmw = x + maxw;
@@ -864,8 +936,7 @@ RealizeMenu(Menu * m)
 	IclassApplyCopy(m->style->bg_iclass, m->win, mmw, mmh, 0, 0,
 			STATE_NORMAL, &(m->pmap), &(m->mask));
 	ESetWindowBackgroundPixmap(disp, m->win, m->pmap);
-	EShapeCombineMask(disp, m->win, ShapeBounding,
-			  0, 0, m->mask, ShapeSet);
+	EShapeCombineMask(disp, m->win, ShapeBounding, 0, 0, m->mask, ShapeSet);
 	for (i = 0; i < m->num; i++)
 	   DrawMenuItem(m, m->items[i], 0);
      }
@@ -900,26 +971,29 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	     GetWinXY(mi->win, &x, &y);
 	     if (!m->style->use_item_bg)
 	       {
-		  mi->pmap[(int)(mi->state)] = ECreatePixmap(disp, mi->win, w, h, id->x.depth);
+		  mi->pmap[(int)(mi->state)] =
+		     ECreatePixmap(disp, mi->win, w, h, id->x.depth);
 		  gc = XCreateGC(disp, m->pmap, 0, &gcv);
-		  XCopyArea(disp, m->pmap, mi->pmap[(int)(mi->state)], gc, x, y, w, h, 0, 0);
+		  XCopyArea(disp, m->pmap, mi->pmap[(int)(mi->state)], gc, x, y,
+			    w, h, 0, 0);
 		  mi->mask[(int)(mi->state)] = None;
 		  if ((mi->state != STATE_NORMAL) || (mi->child))
 		    {
 		       pmap = 0;
 		       mask = 0;
 		       if (mi->child)
-			  IclassApplyCopy(m->style->sub_iclass, mi->win, w, h, 0, 0, mi->state,
-					  &pmap, &mask);
+			  IclassApplyCopy(m->style->sub_iclass, mi->win, w, h,
+					  0, 0, mi->state, &pmap, &mask);
 		       else
-			  IclassApplyCopy(m->style->item_iclass, mi->win, w, h, 0, 0, mi->state,
-					  &pmap, &mask);
+			  IclassApplyCopy(m->style->item_iclass, mi->win, w, h,
+					  0, 0, mi->state, &pmap, &mask);
 		       if (mask)
 			 {
 			    XSetClipMask(disp, gc, mask);
 			    XSetClipOrigin(disp, gc, 0, 0);
 			 }
-		       XCopyArea(disp, pmap, mi->pmap[(int)(mi->state)], gc, 0, 0, w, h, 0, 0);
+		       XCopyArea(disp, pmap, mi->pmap[(int)(mi->state)], gc, 0,
+				 0, w, h, 0, 0);
 		       Imlib_free_pixmap(id, pmap);
 		       if (mask)
 			  Imlib_free_pixmap(id, mask);
@@ -929,19 +1003,21 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	     else
 	       {
 		  if (mi->child)
-		     IclassApplyCopy(m->style->sub_iclass, mi->win, w, h, 0, 0, mi->state,
-				     &(mi->pmap[(int)(mi->state)]), &(mi->mask[(int)(mi->state)]));
+		     IclassApplyCopy(m->style->sub_iclass, mi->win, w, h, 0, 0,
+				     mi->state, &(mi->pmap[(int)(mi->state)]),
+				     &(mi->mask[(int)(mi->state)]));
 		  else
-		     IclassApplyCopy(m->style->item_iclass, mi->win, w, h, 0, 0, mi->state,
-				     &(mi->pmap[(int)(mi->state)]), &(mi->mask[(int)(mi->state)]));
+		     IclassApplyCopy(m->style->item_iclass, mi->win, w, h, 0, 0,
+				     mi->state, &(mi->pmap[(int)(mi->state)]),
+				     &(mi->mask[(int)(mi->state)]));
 	       }
 	  }
      }
    if ((m->style->tclass) && (mi->text))
      {
-	TextDraw(m->style->tclass, mi->pmap[(int)(mi->state)], 0, 0, mi->state,
-		 mi->text, mi->text_x, mi->text_y, mi->text_w, mi->text_h, 17,
-		 m->style->tclass->justification);
+	TextDraw(m->style->tclass, mi->pmap[(int)(mi->state)], 0, 0,
+		 mi->state, mi->text, mi->text_x, mi->text_y, mi->text_w,
+		 mi->text_h, 17, m->style->tclass->justification);
      }
    if (mi->text)
      {
@@ -957,7 +1033,8 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	if (!m->style->use_item_bg)
 	  {
 	     if ((mi->state != STATE_NORMAL) || (mi->child))
-		IclassApply(m->style->item_iclass, mi->win, w, h, 0, 0, mi->state, 0);
+		IclassApply(m->style->item_iclass, mi->win, w, h, 0, 0,
+			    mi->state, 0);
 	     else
 	       {
 		  ESetWindowBackgroundPixmap(disp, mi->win, ParentRelative);
@@ -969,9 +1046,11 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	else
 	  {
 	     if (mi->child)
-		IclassApply(m->style->sub_iclass, mi->win, w, h, 0, 0, mi->state, 0);
+		IclassApply(m->style->sub_iclass, mi->win, w, h, 0, 0,
+			    mi->state, 0);
 	     else
-		IclassApply(m->style->item_iclass, mi->win, w, h, 0, 0, mi->state, 0);
+		IclassApply(m->style->item_iclass, mi->win, w, h, 0, 0,
+			    mi->state, 0);
 	  }
      }
    if ((shape) && (m->style->use_item_bg))
@@ -991,10 +1070,10 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
    struct stat         st;
    const char         *chmap =
 #ifndef __EMX__
-   "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_";
+      "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_";
 
 #else
-   "0123456789abcdefghijklmnopqrstuvwxyz-_";
+      "0123456789abcdefghijklmnopqrstuvwxyz-_";
 
 #endif
    FILE               *f;
@@ -1022,7 +1101,7 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 	   cc = st.st_ctime;
 	Esnprintf(cs, sizeof(cs),
 		  "%s/cached/img/.%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c",
-		  UserEDir(),
+		  UserCacheDir(),
 		  chmap[(aa >> 0) & 0x3f],
 		  chmap[(aa >> 6) & 0x3f],
 		  chmap[(aa >> 12) & 0x3f],
@@ -1039,8 +1118,7 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		  chmap[(cc >> 6) & 0x3f],
 		  chmap[(cc >> 12) & 0x3f],
 		  chmap[(cc >> 18) & 0x3f],
-		  chmap[(cc >> 24) & 0x3f],
-		  chmap[(cc >> 28) & 0x3f]);
+		  chmap[(cc >> 24) & 0x3f], chmap[(cc >> 28) & 0x3f]);
 	/* cached dir listing - use it */
 	if (exists(cs))
 	  {
@@ -1060,7 +1138,9 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		       char                s2[4096], s3[512];
 
 		       word(s, 3, s3);
-		       bg = (Background *) FindItem(s3, 0, LIST_FINDBY_NAME, LIST_TYPE_BACKGROUND);
+		       bg =
+			  (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
+						  LIST_TYPE_BACKGROUND);
 		       if (!bg)
 			 {
 			    ImlibImage         *im;
@@ -1073,14 +1153,15 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 ImlibImage         *im2;
 				 ImlibColor          icl;
 				 char                tile = 1, keep_asp = 0;
-				 int                 width, height, scalex = 0,
-				                     scaley = 0;
-				 int                 scr_asp, im_asp, w2,
-				                     h2;
+				 int                 width, height;
+				 int                 scalex = 0, scaley = 0;
+				 int                 scr_asp, im_asp;
+				 int                 w2, h2;
 				 int                 maxw = 48, maxh = 48;
 				 int                 justx = 512, justy = 512;
 
-				 Esnprintf(s2, sizeof(s2), "%s/cached/img/%s", UserEDir(), s3);
+				 Esnprintf(s2, sizeof(s2), "%s/cached/img/%s",
+					   UserCacheDir(), s3);
 				 width = im->rgb_width;
 				 height = im->rgb_height;
 				 h2 = maxh;
@@ -1088,7 +1169,8 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 if (w2 > maxw)
 				   {
 				      w2 = maxw;
-				      h2 = (im->rgb_height * w2) / im->rgb_width;
+				      h2 =
+					 (im->rgb_height * w2) / im->rgb_width;
 				   }
 				 im2 = Imlib_clone_scaled_image(id, im, w2, h2);
 				 Imlib_save_image_to_ppm(id, im2, s2);
@@ -1107,8 +1189,8 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				      tile = 1;
 				      keep_asp = 0;
 				   }
-				 else if ((!(IN_RANGE(scr_asp, im_asp, 16000))) &&
-					  ((width < 480) && (height < 360)))
+				 else if ((!(IN_RANGE(scr_asp, im_asp, 16000)))
+					  && ((width < 480) && (height < 360)))
 				   {
 				      justx = 0;
 				      justy = 0;
@@ -1147,9 +1229,11 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 icl.r = 0;
 				 icl.g = 0;
 				 icl.b = 0;
-				 bg = CreateDesktopBG(s3, &icl, ss, tile, keep_asp,
-						 justx, justy, scalex, scaley,
-						      NULL, 0, 0, 0, 0, 0);
+				 bg =
+				    CreateDesktopBG(s3, &icl, ss, tile,
+						    keep_asp, justx, justy,
+						    scalex, scaley, NULL, 0, 0,
+						    0, 0, 0);
 				 AddItem(bg, bg->name, 0, LIST_TYPE_BACKGROUND);
 			      }
 			    else
@@ -1163,12 +1247,15 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    ic = CreateIclass();
 			    ic->name = duplicate("`");
 			    ic->norm.normal = CreateImageState();
-			    Esnprintf(stmp, sizeof(stmp), "cached/img/%s", s3);
+			    Esnprintf(stmp, sizeof(stmp), "%s/cached/img/%s",
+				      UserCacheDir(), s3);
 			    ic->norm.normal->im_file = duplicate(stmp);
 			    ic->norm.normal->unloadable = 1;
 			    IclassPopulate(ic);
 			    AddItem(ic, ic->name, 0, LIST_TYPE_ICLASS);
-			    mi = CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET, s3, NULL);
+			    mi =
+			       CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET,
+					      s3, NULL);
 			    AddItemToMenu(m, mi);
 			 }
 		    }
@@ -1287,9 +1374,10 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    chmap[(cc >> 6) & 0x3f],
 			    chmap[(cc >> 12) & 0x3f],
 			    chmap[(cc >> 18) & 0x3f],
-			    chmap[(cc >> 24) & 0x3f],
-			    chmap[(cc >> 28) & 0x3f]);
-		  bg = (Background *) FindItem(s3, 0, LIST_FINDBY_NAME, LIST_TYPE_BACKGROUND);
+			    chmap[(cc >> 24) & 0x3f], chmap[(cc >> 28) & 0x3f]);
+		  bg =
+		     (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
+					     LIST_TYPE_BACKGROUND);
 		  if (!bg)
 		    {
 		       ImlibImage         *im;
@@ -1300,12 +1388,13 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    ImlibImage         *im2;
 			    ImlibColor          icl;
 			    char                tile = 1, keep_asp = 0;
-			    int                 width, height, scalex = 0,
-			                        scaley = 0;
+			    int                 width, height, scalex =
+			       0, scaley = 0;
 			    int                 scr_asp, im_asp, w2, h2;
 			    int                 maxw = 48, maxh = 48;
 
-			    Esnprintf(s2, sizeof(s2), "%s/cached/img/%s", UserEDir(), s3);
+			    Esnprintf(s2, sizeof(s2), "%s/cached/img/%s",
+				      UserCacheDir(), s3);
 			    width = im->rgb_width;
 			    height = im->rgb_height;
 			    h2 = maxh;
@@ -1378,12 +1467,15 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		       ic = CreateIclass();
 		       ic->name = duplicate("`");
 		       ic->norm.normal = CreateImageState();
-		       Esnprintf(stmp, sizeof(stmp), "cached/img/%s", s3);
+		       Esnprintf(stmp, sizeof(stmp), "%s/cached/img/%s",
+				 UserCacheDir(), s3);
 		       ic->norm.normal->im_file = duplicate(stmp);
 		       ic->norm.normal->unloadable = 1;
 		       IclassPopulate(ic);
 		       AddItem(ic, ic->name, 0, LIST_TYPE_ICLASS);
-		       mi = CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET, s3, NULL);
+		       mi =
+			  CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET, s3,
+					 NULL);
 		       AddItemToMenu(m, mi);
 		    }
 		  if (f)
@@ -1440,7 +1532,8 @@ CreateMenuFromFlatFile(char *name, MenuStyle * ms, char *file, Menu * parent)
 }
 
 static void
-FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file, Menu * parent)
+FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file,
+		 Menu * parent)
 {
    FILE               *f;
    char                first = 1;
@@ -1454,93 +1547,99 @@ FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file, Menu * parent
    while (fgets(s, 4096, f))
      {
 	s[strlen(s) - 1] = 0;
-	if (first)
+	if ((s[0]) && s[0] != '#')
 	  {
-	     char               *wd;
-
-	     wd = field(s, 0);
-	     if (wd)
+	     if (first)
 	       {
-		  AddTitleToMenu(m, wd);
-		  Efree(wd);
-	       }
-	     first = 0;
-	  }
-	else
-	  {
-	     char               *txt = NULL, *icon = NULL, *act = NULL;
-	     char               *params = NULL, *tmp = NULL, wd[4096];
+		  char               *wd;
 
-	     MenuItem           *mi;
-	     ImageClass         *icc = NULL;
-	     Menu               *mm;
-	     int                 count = 0;
-
-	     txt = field(s, 0);
-	     icon = field(s, 1);
-	     act = field(s, 2);
-	     params = field(s, 3);
-	     tmp = NULL;
-	     if (icon)
-	       {
-		  Esnprintf(wd, sizeof(wd), "__FM.%s", icon);
-		  icc = FindItem(wd, 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
-		  if (!icc)
+		  wd = field(s, 0);
+		  if (wd)
 		    {
-		       icc = CreateIclass();
-		       icc->name = duplicate(wd);
-		       icc->norm.normal = CreateImageState();
-		       icc->norm.normal->im_file = icon;
-		       IclassPopulate(icc);
-		       AddItem(icc, icc->name, 0, LIST_TYPE_ICLASS);
+		       AddTitleToMenu(m, wd);
+		       Efree(wd);
+		    }
+		  first = 0;
+	       }
+	     else
+	       {
+		  char               *txt = NULL, *icon = NULL, *act = NULL;
+		  char               *params = NULL, *tmp = NULL, wd[4096];
+
+		  MenuItem           *mi;
+		  ImageClass         *icc = NULL;
+		  Menu               *mm;
+		  int                 count = 0;
+
+		  txt = field(s, 0);
+		  icon = field(s, 1);
+		  act = field(s, 2);
+		  params = field(s, 3);
+		  tmp = NULL;
+		  if (icon)
+		    {
+		       Esnprintf(wd, sizeof(wd), "__FM.%s", icon);
+		       icc =
+			  FindItem(wd, 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		       if (!icc)
+			 {
+			    icc = CreateIclass();
+			    icc->name = duplicate(wd);
+			    icc->norm.normal = CreateImageState();
+			    icc->norm.normal->im_file = icon;
+			    IclassPopulate(icc);
+			    AddItem(icc, icc->name, 0, LIST_TYPE_ICLASS);
+			 }
+		       else
+			 {
+			    Efree(icon);
+			 }
+		    }
+		  if ((act) && (!strcmp(act, "exec")) && (params))
+		    {
+		       word(params, 1, wd);
+		       tmp = pathtoexec(wd);
+		       if (tmp)
+			 {
+			    Efree(tmp);
+
+			    mi =
+			       CreateMenuItem(txt, icc, ACTION_EXEC, params,
+					      NULL);
+			    AddItemToMenu(m, mi);
+			    if (txt)
+			       Efree(txt);
+			    if (params)
+			       Efree(params);
+			 }
+		    }
+		  else if ((act) && (!strcmp(act, "menu")) && (params))
+		    {
+		       Esnprintf(wd, sizeof(wd), "__FM.%s.%i", name, count);
+		       count++;
+		       mm = CreateMenuFromFlatFile(wd, ms, params, parent);
+		       if (mm)
+			 {
+			    mm->parent = m;
+			    AddItem(mm, mm->name, mm->win, LIST_TYPE_MENU);
+			    mi = CreateMenuItem(txt, icc, 0, NULL, mm);
+			    AddItemToMenu(m, mi);
+			 }
+		       if (txt)
+			  Efree(txt);
 		    }
 		  else
 		    {
-		       Efree(icon);
-		    }
-	       }
-	     if ((act) && (!strcmp(act, "exec")) && (params))
-	       {
-		  word(params, 1, wd);
-		  tmp = pathtoexec(wd);
-		  if (tmp)
-		    {
-		       Efree(tmp);
-
-		       mi = CreateMenuItem(txt, icc, ACTION_EXEC, params, NULL);
+		       mi = CreateMenuItem(txt, icc, 0, NULL, NULL);
 		       AddItemToMenu(m, mi);
 		       if (txt)
 			  Efree(txt);
 		       if (params)
 			  Efree(params);
 		    }
+		  if (act)
+		     Efree(act);
 	       }
-	     else if ((act) && (!strcmp(act, "menu")) && (params))
-	       {
-		  Esnprintf(wd, sizeof(wd), "__FM.%s.%i", name, count);
-		  count++;
-		  mm = CreateMenuFromFlatFile(wd, ms, params, parent);
-		  if (mm)
-		    {
-		       mm->parent = m;
-		       AddItem(mm, mm->name, mm->win, LIST_TYPE_MENU);
-		       mi = CreateMenuItem(txt, icc, 0, NULL, mm);
-		       AddItemToMenu(m, mi);
-		    }
-		  if (txt)
-		     Efree(txt);
-	       }
-	     else
-	       {
-		  mi = CreateMenuItem(txt, icc, 0, NULL, NULL);
-		  AddItemToMenu(m, mi);
-		  if (txt)
-		     Efree(txt);
-		  if (params)
-		     Efree(params);
-	       }
-	     if (act)
-		Efree(act);
 	  }
      }
    fclose(f);
@@ -1607,7 +1706,7 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 
    EDBUG(5, "CreateMenuFromGnome");
 
-   if ((lang = getenv("LANG")) != NULL)
+   if ((lang = setlocale(LC_MESSAGES, NULL)) != NULL)
       Esnprintf(name_buf, sizeof(name_buf), "Name[%s]=", lang);
    else
       name_buf[0] = '\0';
@@ -1658,8 +1757,8 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 #endif
 		  if (f)
 		    {
-		       char               *iname = NULL, *exec = NULL, *texec = NULL,
-		                          *tmp;
+		       char               *iname = NULL, *exec = NULL, *texec =
+			  NULL, *tmp;
 		       char               *en_name = NULL;
 
 		       while (fgets(s, sizeof(s), f))
@@ -1671,7 +1770,8 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 			    else if (name_buf[0] &&
 				     !strncmp(s, name_buf, strlen(name_buf)))
 			       iname = duplicate(&(s[strlen(name_buf)]));
-			    else if (!strncmp(s, "TryExec=", strlen("TryExec=")))
+			    else
+			       if (!strncmp(s, "TryExec=", strlen("TryExec=")))
 			       texec = duplicate(&(s[strlen("TryExec=")]));
 			    else if (!strncmp(s, "Exec=", strlen("Exec=")))
 			       exec = duplicate(&(s[strlen("Exec=")]));
@@ -1697,7 +1797,9 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 				 if (tmp)
 				    Efree(tmp);
 
-				 mi = CreateMenuItem(iname, NULL, ACTION_EXEC, exec, NULL);
+				 mi =
+				    CreateMenuItem(iname, NULL, ACTION_EXEC,
+						   exec, NULL);
 				 AddItemToMenu(m, mi);
 			      }
 			 }
@@ -1781,7 +1883,9 @@ CreateMenuFromBorders(char *name, MenuStyle * ms)
 	/* if its not internal (ie doesnt start with _ ) */
 	if (lst[i]->name[0] != '_')
 	  {
-	     mi = CreateMenuItem(lst[i]->name, NULL, ACTION_SET_WINDOW_BORDER, lst[i]->name, NULL);
+	     mi =
+		CreateMenuItem(lst[i]->name, NULL, ACTION_SET_WINDOW_BORDER,
+			       lst[i]->name, NULL);
 	     AddItemToMenu(m, mi);
 	  }
      }
@@ -1810,10 +1914,13 @@ CreateMenuFromAllEWins(char *name, MenuStyle * ms)
      {
 	for (i = 0; i < num; i++)
 	  {
-	     if ((!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist) && (lst[i]->client.title) && (!lst[i]->ibox))
+	     if ((!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist)
+		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi = CreateMenuItem(lst[i]->client.title, NULL, ACTION_FOCUS_SET, s, NULL);
+		  mi =
+		     CreateMenuItem(lst[i]->client.title, NULL,
+				    ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(m, mi);
 	       }
 	  }
@@ -1843,10 +1950,13 @@ CreateMenuFromDesktopEWins(char *name, MenuStyle * ms, int desk)
 	for (i = 0; i < num; i++)
 	  {
 	     if (((lst[i]->desktop == desk) || (lst[i]->sticky)) &&
-		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist) && (lst[i]->client.title) && (!lst[i]->ibox))
+		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist)
+		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi = CreateMenuItem(lst[i]->client.title, NULL, ACTION_FOCUS_SET, s, NULL);
+		  mi =
+		     CreateMenuItem(lst[i]->client.title, NULL,
+				    ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(m, mi);
 	       }
 	  }
@@ -1877,20 +1987,25 @@ CreateMenuFromDesktops(char *name, MenuStyle * ms)
 	mm->name = duplicate("__SUBMENUDESK_E");
 	mm->style = ms;
 	Esnprintf(s, sizeof(s), "%i", j);
-	mi = CreateMenuItem("Go to this Desktop", NULL, ACTION_GOTO_DESK, s, NULL);
+	mi =
+	   CreateMenuItem(_("Go to this Desktop"), NULL, ACTION_GOTO_DESK,
+			  s, NULL);
 	AddItemToMenu(mm, mi);
 	for (i = 0; i < num; i++)
 	  {
 	     if (((lst[i]->desktop == j) || (lst[i]->sticky)) &&
-		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist) && (lst[i]->client.title) && (!lst[i]->ibox))
+		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist)
+		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi = CreateMenuItem(lst[i]->client.title, NULL, ACTION_FOCUS_SET, s, NULL);
+		  mi =
+		     CreateMenuItem(lst[i]->client.title, NULL,
+				    ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(mm, mi);
 	       }
 	  }
 	mm->parent = m;
-	Esnprintf(s, sizeof(s), "Desktop %i", j);
+	Esnprintf(s, sizeof(s), _("Desktop %i"), j);
 	mi = CreateMenuItem(s, NULL, 0, NULL, mm);
 	AddItemToMenu(m, mi);
      }
@@ -1952,19 +2067,25 @@ CreateMenuFromGroups(char *name, MenuStyle * ms)
 	     mm->name = duplicate("__SUBMENUGROUP_E");
 	     mm->style = ms;
 	     Esnprintf(s, sizeof(s), "%i", lst[i]->members[0]->client.win);
-	     mi = CreateMenuItem("Show/Hide this group", NULL, ACTION_SHOW_HIDE_GROUP, s, NULL);
+	     mi =
+		CreateMenuItem(_("Show/Hide this group"), NULL,
+			       ACTION_SHOW_HIDE_GROUP, s, NULL);
 	     AddItemToMenu(mm, mi);
-	     mi = CreateMenuItem("Iconify this group", NULL, ACTION_ICONIFY, s, NULL);
+	     mi =
+		CreateMenuItem(_("Iconify this group"), NULL,
+			       ACTION_ICONIFY, s, NULL);
 	     AddItemToMenu(mm, mi);
 
 	     for (j = 0; j < lst[i]->num_members; j++)
 	       {
 		  Esnprintf(s, sizeof(s), "%i", lst[i]->members[j]->client.win);
-		  mi = CreateMenuItem(lst[i]->members[j]->client.title, NULL, ACTION_FOCUS_SET, s, NULL);
+		  mi =
+		     CreateMenuItem(lst[i]->members[j]->client.title, NULL,
+				    ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(mm, mi);
 	       }
 	     mm->parent = m;
-	     Esnprintf(s, sizeof(s), "Group %i", i);
+	     Esnprintf(s, sizeof(s), _("Group %i"), i);
 	     mi = CreateMenuItem(s, NULL, 0, NULL, mm);
 	     AddItemToMenu(m, mi);
 	  }
