@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -29,6 +29,7 @@ extern char        *__XOS2RedirRoot(const char *);
 void                EdgeTimeout(int val, void *data);
 
 static char        *dir = NULL;
+static char        *cacheDir = NULL;
 
 void
 BlumFlimFrub(void)
@@ -37,50 +38,50 @@ BlumFlimFrub(void)
    char                s[1024];
    char               *bins[3] =
 #ifndef __EMX__
-   {"dox", "eesh", "epp"};
+   { "dox", "eesh", "epp" };
 
 #else
-   {"dox.exe", "eesh.exe", "epp.exe"};
+   { "dox.exe", "eesh.exe", "epp.exe" };
 
 #endif
    char               *docs[4] =
-   {"E-docs/MAIN", "E-docs/Edoc_bg.png", "E-docs/E_logo.png"};
-   char               *thms[1] =
-   {"themes/DEFAULT/epplets/epplets.cfg"};
+      { "E-docs/MAIN", "E-docs/Edoc_bg.png", "E-docs/E_logo.png" };
+   char               *thms[1] = { "themes/DEFAULT/epplets/epplets.cfg" };
 
    for (i = 0; i < 3; i++)
      {
 #ifndef __EMX__
 	Esnprintf(s, sizeof(s), "%s/%s", ENLIGHTENMENT_BIN, bins[i]);
 #else
-	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_BIN), bins[i]);
+	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_BIN),
+		  bins[i]);
 #endif
 	if (!exists(s))
 	  {
-	     Alert("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		   "\n"
-		   "Enlightenment's utility executable cannot be found at:\n"
-		   "\n"
-		   "%s\n"
-		"This is a fatal error and Enlightenment will cease to run.\n"
-		   "Please rectify this situation and ensure it is installed\n"
-		   "correctly.\n"
-		   "\n"
-		   "The reason this could be missing is due to badly created\n"
-	       "packages, someone manually deleting that program or perhaps\n"
-		   "an error in installing Enlightenment.\n", s);
+	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
+		     "\n"
+		     "Enlightenment's utility executable cannot be found at:\n"
+		     "\n"
+		     "%s\n"
+		     "This is a fatal error and Enlightenment will cease to run.\n"
+		     "Please rectify this situation and ensure it is installed\n"
+		     "correctly.\n"
+		     "\n"
+		     "The reason this could be missing is due to badly created\n"
+		     "packages, someone manually deleting that program or perhaps\n"
+		     "an error in installing Enlightenment.\n"), s);
 	     EExit(NULL);
 	  }
 	if (!canexec(s))
 	  {
-	     Alert("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		   "\n"
-		"Enlightenment's dox executable is not able to be executed:\n"
-		   "\n"
-		   "%s\n"
-		"This is a fatal error and Enlightenment will cease to run.\n"
-		 "Please rectify this situation and ensure dox is installed\n"
-		   "correctly.\n", s);
+	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
+		     "\n"
+		     "Enlightenment's dox executable is not able to be executed:\n"
+		     "\n"
+		     "%s\n"
+		     "This is a fatal error and Enlightenment will cease to run.\n"
+		     "Please rectify this situation and ensure dox is installed\n"
+		     "correctly.\n"), s);
 	     EExit(NULL);
 	  }
 	Esnprintf(s, sizeof(s), "%s/dox", ENLIGHTENMENT_BIN);
@@ -90,21 +91,22 @@ BlumFlimFrub(void)
 #ifndef __EMX__
 	Esnprintf(s, sizeof(s), "%s/%s", ENLIGHTENMENT_ROOT, docs[i]);
 #else
-	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_ROOT), docs[i]);
+	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_ROOT),
+		  docs[i]);
 #endif
 	if (!exists(s))
 	  {
-	     Alert("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		   "\n"
-		   "Enlightenment's documentation is not present or correctly installed\n"
-		   "\n"
-		"This is a fatal error and Enlightenment will cease to run.\n"
-		   "Please rectify this situation and ensure it is installed\n"
-		   "correctly.\n"
-		   "\n"
-		   "The reason this could be missing is due to badly created\n"
-		"packages, someone manually deleting those files or perhaps\n"
-		   "an error in installing Enlightenment.\n");
+	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
+		     "\n"
+		     "Enlightenment's documentation is not present or correctly installed\n"
+		     "\n"
+		     "This is a fatal error and Enlightenment will cease to run.\n"
+		     "Please rectify this situation and ensure it is installed\n"
+		     "correctly.\n"
+		     "\n"
+		     "The reason this could be missing is due to badly created\n"
+		     "packages, someone manually deleting those files or perhaps\n"
+		     "an error in installing Enlightenment.\n"));
 	     EExit(NULL);
 	  }
      }
@@ -113,20 +115,21 @@ BlumFlimFrub(void)
 #ifndef __EMX__
 	Esnprintf(s, sizeof(s), "%s/%s", ENLIGHTENMENT_ROOT, thms[i]);
 #else
-	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_ROOT), thms[i]);
+	Esnprintf(s, sizeof(s), "%s/%s", __XOS2RedirRoot(ENLIGHTENMENT_ROOT),
+		  thms[i]);
 #endif
 	if (!exists(s))
 	  {
-	     Alert("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		   "\n"
-		   "Enlightenment's DEFAULT installed theme is missing or inadequately\n"
-		   "configured to be a useful DEFAULT theme.\n"
-		   "\n"
-		"This is a fatal error and Enlightenment will cease to run.\n"
-		   "Please rectify this situation and ensure it is installed\n"
-	     "correctly. The DEFAULT theme Enlightenment comes with normally\n"
-		   "is BrushedMetal-Tigert and this theme is adequate for a DEFAULT\n"
-		   "theme.\n");
+	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
+		     "\n"
+		     "Enlightenment's DEFAULT installed theme is missing or inadequately\n"
+		     "configured to be a useful DEFAULT theme.\n"
+		     "\n"
+		     "This is a fatal error and Enlightenment will cease to run.\n"
+		     "Please rectify this situation and ensure it is installed\n"
+		     "correctly. The DEFAULT theme Enlightenment comes with normally\n"
+		     "is BrushedMetal-Tigert and this theme is adequate for a DEFAULT\n"
+		     "theme.\n"));
 	     EExit(NULL);
 	  }
      }
@@ -155,6 +158,20 @@ UserEDir(void)
    return dir;
 }
 
+void
+SetCacheDir(char *d)
+{
+   cacheDir = duplicate(d);
+}
+
+char               *
+UserCacheDir(void)
+{
+   if (!cacheDir)
+      cacheDir = duplicate(UserEDir());
+   return cacheDir;
+}
+
 int
 EExit(void *code)
 {
@@ -254,19 +271,19 @@ ShowEdgeWindows(void)
    GetCurrentArea(&cx, &cy);
    GetAreaSize(&ax, &ay);
 
-   if (cx == 0)
+   if (cx == 0 && !mode.area_wraparound)
       EUnmapWindow(disp, w1);
    else
       EMapRaised(disp, w1);
-   if (cx == (ax - 1))
+   if (cx == (ax - 1) && !mode.area_wraparound)
       EUnmapWindow(disp, w2);
    else
       EMapRaised(disp, w2);
-   if (cy == 0)
+   if (cy == 0 && !mode.area_wraparound)
       EUnmapWindow(disp, w3);
    else
       EMapRaised(disp, w3);
-   if (cy == (ay - 1))
+   if (cy == (ay - 1) && !mode.area_wraparound)
       EUnmapWindow(disp, w4);
    else
       EMapRaised(disp, w4);
@@ -374,25 +391,25 @@ EdgeTimeout(int val, void *data)
    switch (val)
      {
      case 0:
-	if (ax == 0)
+	if (ax == 0 && !mode.area_wraparound)
 	   return;
 	dx = root.w - 2;
 	dax = -1;
 	break;
      case 1:
-	if (ax == (aw - 1))
+	if (ax == (aw - 1) && !mode.area_wraparound)
 	   return;
 	dx = -(root.w - 2);
 	dax = 1;
 	break;
      case 2:
-	if (ay == 0)
+	if (ay == 0 && !mode.area_wraparound)
 	   return;
 	dy = root.h - 2;
 	day = -1;
 	break;
      case 3:
-	if (ay == (ah - 1))
+	if (ay == (ah - 1) && !mode.area_wraparound)
 	   return;
 	dy = -(root.h - 2);
 	day = 1;
@@ -403,6 +420,10 @@ EdgeTimeout(int val, void *data)
    mode.flipp = 1;
    MoveCurrentAreaBy(dax, day);
    mode.flipp = 0;
+   if (aw == 1)
+      dx = 0;
+   if (ah == 1)
+      dy = 0;
    XWarpPointer(disp, None, None, 0, 0, 0, 0, dx, dy);
    data = NULL;
 }
@@ -417,93 +438,93 @@ SanitiseThemeDir(char *dir)
    Esnprintf(s, sizeof(s), "%s/%s", dir, "borders.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a borders.cfg file\n";
+	badreason = _("Theme does not contain a borders.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "buttons.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a buttons.cfg file\n";
+	badreason = _("Theme does not contain a buttons.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "colormodifiers.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a colormodifiers.cfg file\n";
+	badreason = _("Theme does not contain a colormodifiers.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "cursors.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a cursors.cfg file\n";
+	badreason = _("Theme does not contain a cursors.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "desktops.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a desktops.cfg file\n";
+	badreason = _("Theme does not contain a desktops.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "imageclasses.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a imageclasses.cfg file\n";
+	badreason = _("Theme does not contain a imageclasses.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "init.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a init.cfg file\n";
+	badreason = _("Theme does not contain a init.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "menustyles.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a menustyles.cfg file\n";
+	badreason = _("Theme does not contain a menustyles.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "slideouts.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a slideouts.cfg file\n";
+	badreason = _("Theme does not contain a slideouts.cfg file\n");
 	return 0;
      }
 #ifndef __EMX__			/* OS/2 Team will compile ESound after XMMS project */
    Esnprintf(s, sizeof(s), "%s/%s", dir, "sound.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a sound.cfg file\n";
+	badreason = _("Theme does not contain a sound.cfg file\n");
 	return 0;
      }
 #endif
    Esnprintf(s, sizeof(s), "%s/%s", dir, "tooltips.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a tooltips.cfg file\n";
+	badreason = _("Theme does not contain a tooltips.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "windowmatches.cfg");
    if (!isfile(s))
      {
-	badreason = "Theme does not contain a windowmatches.cfg file\n";
+	badreason = _("Theme does not contain a windowmatches.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "menus.cfg");
    if (isfile(s))
      {
-	badreason = "Theme contains a menus.cfg file\n";
+	badreason = _("Theme contains a menus.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "control.cfg");
    if (isfile(s))
      {
-	badreason = "Theme contains a control.cfg file\n";
+	badreason = _("Theme contains a control.cfg file\n");
 	return 0;
      }
    Esnprintf(s, sizeof(s), "%s/%s", dir, "keybindings.cfg");
    if (isfile(s))
      {
-	badreason = "Theme contains a keybindings.cfg file\n";
+	badreason = _("Theme contains a keybindings.cfg file\n");
 	return 0;
      }
    return 1;
