@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -47,10 +47,10 @@ Emkstemp(char *template)
 {
    static const char   letters[]
 #ifndef __EMX__
-   = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
+      = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
 
 #else
-   = "abcdefghijklmnopqrstuvwxyz0123456789";
+      = "abcdefghijklmnopqrstuvwxyz0123456789";
 
 #endif
 
@@ -140,16 +140,16 @@ static char        *userthemepath;
 /* The saved window details */
 static int          num_match = 0;
 typedef struct _match
-  {
-     char               *session_id;
-     char               *name;
-     char               *class;
-     char               *role;
-     char               *command;
-     char                used;
-     int                 x, y, w, h, desktop, iconified, shaded, sticky,
-                         layer;
-  }
+{
+   char               *session_id;
+   char               *name;
+   char               *class;
+   char               *role;
+   char               *command;
+   char                used;
+   int                 x, y, w, h;
+   int                 desktop, iconified, shaded, sticky, layer;
+}
 Match;
 
 Match              *matches = NULL;
@@ -214,8 +214,12 @@ SaveWindowStates(void)
 		       y = 0;
 		       if (!ewin->sticky)
 			 {
-			    x = desks.desk[ewin->desktop].current_area_x * root.w;
-			    y = desks.desk[ewin->desktop].current_area_y * root.h;
+			    x =
+			       desks.desk[ewin->desktop].current_area_x *
+			       root.w;
+			    y =
+			       desks.desk[ewin->desktop].current_area_y *
+			       root.h;
 			 }
 		       fprintf(f, "[CLIENT] %i %i %i %i %i %i %i %i %i\n",
 			       ewin->x + x, ewin->y + y,
@@ -239,13 +243,12 @@ SaveWindowStates(void)
 	     rm(ss);
 	     mv(s, ss);
 	     if (!isfile(ss))
-		Alert("There was an error writing the clients "
-		      "session save file.\n"
-		      "You may have run out of disk "
-		      "space, not have permission\n"
-		      "to write to your filing system "
-		      "or other similar problems.\n"
-		   );
+		Alert(_("There was an error writing the clients "
+			"session save file.\n"
+			"You may have run out of disk "
+			"space, not have permission\n"
+			"to write to your filing system "
+			"or other similar problems.\n"));
 	  }
 	Efree(lst);
      }
@@ -288,8 +291,7 @@ LoadWindowStates(void)
 			 &(matches[num_match - 1].iconified),
 			 &(matches[num_match - 1].shaded),
 			 &(matches[num_match - 1].sticky),
-			 &(matches[num_match - 1].layer)
-		     );
+			 &(matches[num_match - 1].layer));
 	       }
 	     else if (!strcmp(s1, "[SESSION_ID]"))
 	       {
@@ -426,15 +428,15 @@ autosave(void)
      {
 	char                s[4096];
 
-	SaveSnapInfo();
+	Real_SaveSnapInfo(0, NULL);
 	Etmp(s);
 	SaveUserControlConfig(fopen(s, "w"));
 	rm(GetGenericSMFile());
 	mv(s, GetGenericSMFile());
 	if (!isfile(GetGenericSMFile()))
-	   Alert("There was an error saving your autosave data - filing\n"
-		 "system problems.\n"
-	      );
+	   Alert(_
+		 ("There was an error saving your autosave data - filing\n"
+		  "system problems.\n"));
 /*      
  * if (strcmp(GetSMFile(), GetGenericSMFile()))
  * {
@@ -447,10 +449,10 @@ autosave(void)
    else
      {
 /*      char                buf[1024];
- * 
- * * * Esnprintf(buf, sizeof(buf) / sizeof(char), "rm %s*", GetSMFile());
- * * * 
- * * * system(buf); */
+ *
+ *      Esnprintf(buf, sizeof(buf) / sizeof(char), "rm %s*", GetSMFile());
+ *      system(buf); */
+
 	rm(GetGenericSMFile());
      }
 }
@@ -557,15 +559,18 @@ doSMExit(void *params)
 	     if (themepath[0] != 0)
 	       {
 		  Esnprintf(sss, sizeof(sss),
-		     "exec %s -single -ext_init_win %i -theme %s -display %s",
-			    command, w, themename, dstr);
+			    "exec %s -single -ext_init_win %i -theme %s "
+			    "-econfdir %s -ecachedir %s -display %s",
+			    command, w, themename,
+			    UserEDir(), UserCacheDir(), dstr);
 		  execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	       }
 	     else
 	       {
 		  Esnprintf(sss, sizeof(sss),
-			    "exec %s -single -ext_init_win %i -display %s",
-			    command, w, dstr);
+			    "exec %s -single -ext_init_win %i "
+			    "-econfdir %s -ecachedir %s -display %s",
+			    command, w, UserEDir(), UserCacheDir(), dstr);
 		  execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	       }
 	  }
@@ -579,8 +584,9 @@ doSMExit(void *params)
 	     disp = NULL;
 	     sscanf(params, "%*s %1000s", s);
 	     Esnprintf(sss, sizeof(sss),
-		     "exec %s -single -ext_init_win %i -theme %s -display %s",
-		       command, w, s, dstr);
+		       "exec %s -single -ext_init_win %i -theme %s "
+		       "-econfdir %s -ecachedir %s -display %s",
+		       command, w, s, UserEDir(), UserCacheDir(), dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	  }
 	else if (!strcmp(s, "restart_wm"))
@@ -596,7 +602,9 @@ doSMExit(void *params)
 	     if (atword(params, 2))
 		strncpy(s, atword(params, 2), 1000);
 	     real_exec = (char *)Emalloc(strlen(s) + 6);
-	     sprintf(real_exec, "exec %s -display %s", s, dstr);
+	     sprintf(real_exec, "exec %s "
+		     "-econfdir %s -ecachedir %s -display %s",
+		     s, UserEDir(), UserCacheDir(), dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", "exec",
 		   real_exec, NULL);
 	  }
@@ -615,9 +623,7 @@ doSMExit(void *params)
 				"\n"
 				"\n"
 				"    Are you sure you wish to log out ?    \n"
-				"\n"
-				"\n"
-		     );
+				"\n" "\n");
 		  DialogAddButton(d, "  Yes, Log Out  ", LogoutCB, 1);
 		  DialogAddButton(d, "  No  ", NULL, 1);
 		  DialogBindKey(d, "Escape", CB_SettingsEscape, 0, d);
@@ -627,8 +633,58 @@ doSMExit(void *params)
 	     ewin = FindEwinByDialog(d);
 	     if (ewin)
 	       {
-		  MoveEwin(ewin, ((root.w - (ewin->w)) / 2), ((root.h - (ewin->h)) / 2));
-		  FocusToEWin(ewin);
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       Window              rt, ch;
+		       XineramaScreenInfo *screens;
+		       int                 pointer_x, pointer_y;
+		       int                 num;
+		       int                 d;
+		       unsigned int        ud;
+		       int                 i;
+
+		       XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
+				     &pointer_y, &d, &d, &ud);
+		       screens = XineramaQueryScreens(disp, &num);
+		       for (i = 0; i < num; i++)
+			 {
+			    if (pointer_x >= screens[i].x_org)
+			      {
+				 if (pointer_x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (pointer_y >= screens[i].y_org)
+					{
+					   if (pointer_y <= (screens[i].height +
+							     screens[i].y_org))
+					     {
+						ewin->x =
+						   ((screens[i].width - ewin->w)
+						    / 2) + screens[i].x_org;
+						ewin->y =
+						   ((screens
+						     [i].height -
+						     ewin->h) / 2) +
+						   screens[i].y_org;
+					     }
+					}
+				   }
+			      }
+			 }
+		       XFree(screens);
+		       MoveEwin(ewin, ewin->x, ewin->y);
+		       FocusToEWin(ewin);
+		    }
+		  else
+		    {
+#endif
+		       MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
+				((root.h - (ewin->h)) / 2));
+		       FocusToEWin(ewin);
+#ifdef HAS_XINERAMA
+		    }
+#endif
 	       }
 	     return;
 	  }
@@ -651,15 +707,19 @@ static int          restarting = False;
 
 static void         LogoutCB(int val, void *data);
 static void         set_save_props(SmcConn smc_conn, int master_flag);
-static void         callback_save_yourself2(SmcConn smc_conn, SmPointer client_data);
+static void         callback_save_yourself2(SmcConn smc_conn,
+
+					    SmPointer client_data);
 static void         callback_save_yourself(SmcConn smc_conn,
-					SmPointer client_data, int save_style,
-					   Bool shutdown, int interact_style,
-					   Bool fast);
+					   SmPointer client_data,
+					   int save_style, Bool shutdown,
+					   int interact_style, Bool fast);
 static void         callback_die(SmcConn smc_conn, SmPointer client_data);
 static void         callback_save_complete(SmcConn smc_conn,
+
 					   SmPointer client_data);
 static void         callback_shutdown_cancelled(SmcConn smc_conn,
+
 						SmPointer client_data);
 
 static void
@@ -671,6 +731,10 @@ set_save_props(SmcConn smc_conn, int master_flag)
    char               *smid = "-smid";
    char               *single = "-single";
    char               *smfile = "-smfile";
+   char               *econfdir = "-econfdir";
+   char               *e_conf_dir;
+   char               *ecachedir = "-ecachedir";
+   char               *e_cache_dir;
    char               *extinitwin = "-ext_init_win";
    char               *sh = "sh";
    char               *c = "-c";
@@ -678,17 +742,14 @@ set_save_props(SmcConn smc_conn, int master_flag)
    char                priority = 10;
    char                style;
    int                 n = 0;
-   SmPropValue         programVal =
-   {0, NULL};
-   SmPropValue         userIDVal =
-   {0, NULL};
-   SmPropValue         discardVal[] =
-   {
+   SmPropValue         programVal = { 0, NULL };
+   SmPropValue         userIDVal = { 0, NULL };
+   SmPropValue         discardVal[] = {
       {0, NULL},
       {0, NULL},
-      {0, NULL}};
-   SmPropValue         restartVal[] =
-   {
+      {0, NULL}
+   };
+   SmPropValue         restartVal[] = {
       {0, NULL},
       {0, NULL},
       {0, NULL},
@@ -698,11 +759,10 @@ set_save_props(SmcConn smc_conn, int master_flag)
       {0, NULL},
       {0, NULL},
       {0, NULL},
-      {0, NULL}};
-   SmPropValue         styleVal =
-   {0, NULL};
-   SmPropValue         priorityVal =
-   {0, NULL};
+      {0, NULL}
+   };
+   SmPropValue         styleVal = { 0, NULL };
+   SmPropValue         priorityVal = { 0, NULL };
    SmProp              programProp;
    SmProp              userIDProp;
    SmProp              discardProp;
@@ -761,6 +821,8 @@ set_save_props(SmcConn smc_conn, int master_flag)
       style = SmRestartNever;
 
    user = username(getuid());
+   e_conf_dir = UserEDir();
+   e_cache_dir = UserCacheDir();
    /* The SM specs state that the SmProgram should be the argument passed
     * to execve. Passing argv[0] is close enough. */
    program = command;
@@ -808,6 +870,14 @@ set_save_props(SmcConn smc_conn, int master_flag)
    restartVal[n++].value = smid;
    restartVal[n].length = strlen(sm_client_id);
    restartVal[n++].value = sm_client_id;
+   restartVal[n].length = strlen(econfdir);
+   restartVal[n++].value = econfdir;
+   restartVal[n].length = strlen(e_conf_dir);
+   restartVal[n++].value = e_conf_dir;
+   restartVal[n].length = strlen(ecachedir);
+   restartVal[n++].value = ecachedir;
+   restartVal[n].length = strlen(e_cache_dir);
+   restartVal[n++].value = e_cache_dir;
 
    restartProp.num_vals = n;
 
@@ -1016,18 +1086,15 @@ ProcessICEMSGS(void)
    if (status == IceProcessMessagesIOError)
      {
 	/* Less of the hope.... E survives */
-	DialogAlert("ERROR!\n"
-		    "\n"
-		    "Lost the Session Manager that was there?\n"
-		    "Here here session manager... come here... want a bone?\n"
-		    "Oh come now! Stop sulking! Bugger. Oh well. "
-		    "Will continue without\n"
-		    "a session manager.\n"
-		    "\n"
-		    "I'll survive somehow.\n"
-		    "\n"
-		    "\n"
-		    "... I hope.\n");
+	DialogAlert(_("ERROR!\n"
+		      "\n"
+		      "Lost the Session Manager that was there?\n"
+		      "Here here session manager... come here... want a bone?\n"
+		      "Oh come now! Stop sulking! Bugger. Oh well. "
+		      "Will continue without\n"
+		      "a session manager.\n"
+		      "\n"
+		      "I'll survive somehow.\n" "\n" "\n" "... I hope.\n"));
 	SmcCloseConnection(sm_conn, 0, NULL);
 	sm_conn = NULL;
 	sm_fd = -1;
@@ -1158,16 +1225,14 @@ doSMExit(void *params)
 	  {
 	     AUDIO_PLAY("SOUND_LOGOUT");
 	     d = CreateDialog("LOGOUT_DIALOG");
-	     DialogSetTitle(d, "Are you sure?");
+	     DialogSetTitle(d, _("Are you sure?"));
 	     DialogSetText(d,
-			   "\n"
-			   "\n"
-			   "    Are you sure you wish to log out ?    \n"
-			   "\n"
-			   "\n"
-		);
-	     DialogAddButton(d, "  Yes, Log Out  ", LogoutCB, 1);
-	     DialogAddButton(d, "  No  ", NULL, 1);
+			   _("\n"
+			     "\n"
+			     "    Are you sure you wish to log out ?    \n"
+			     "\n" "\n"));
+	     DialogAddButton(d, _("  Yes, Log Out  "), LogoutCB, 1);
+	     DialogAddButton(d, _("  No  "), NULL, 1);
 	     DialogBindKey(d, "Escape", CB_SettingsEscape, 1, d);
 	     DialogBindKey(d, "Return", LogoutCB, 0, d);
 	  }
@@ -1175,8 +1240,58 @@ doSMExit(void *params)
 	ewin = FindEwinByDialog(d);
 	if (ewin)
 	  {
-	     MoveEwin(ewin, ((root.w - (ewin->w)) / 2), ((root.h - (ewin->h)) / 2));
-	     FocusToEWin(ewin);
+#ifdef HAS_XINERAMA
+	     if (xinerama_active)
+	       {
+		  Window              rt, ch;
+		  XineramaScreenInfo *screens;
+		  int                 pointer_x, pointer_y;
+		  int                 num;
+		  int                 d;
+		  int                 i;
+		  unsigned int        ud;
+
+		  XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
+				&pointer_y, &d, &d, &ud);
+		  screens = XineramaQueryScreens(disp, &num);
+		  for (i = 0; i < num; i++)
+		    {
+		       if (pointer_x >= screens[i].x_org)
+			 {
+			    if (pointer_x <=
+				(screens[i].width + screens[i].x_org))
+			      {
+				 if (pointer_y >= screens[i].y_org)
+				   {
+				      if (pointer_y <= (screens[i].height +
+							screens[i].y_org))
+					{
+					   ewin->x =
+					      ((screens[i].width - ewin->w) /
+					       2) + screens[i].x_org;
+					   ewin->y =
+					      ((screens[i].height - ewin->h) /
+					       2) + screens[i].y_org;
+					}
+				   }
+			      }
+			 }
+		    }
+		  XFree(screens);
+		  MoveEwin(ewin, ewin->x, ewin->y);
+		  FocusToEWin(ewin);
+	       }
+	     else
+	       {
+#endif
+
+		  MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
+			   ((root.h - (ewin->h)) / 2));
+		  FocusToEWin(ewin);
+#ifdef HAS_XINERAMA
+	       }
+#endif
+
 	  }
 	return;
      }
@@ -1188,8 +1303,7 @@ doSMExit(void *params)
 	   KDE_Shutdown();
 	XCloseDisplay(disp);
 	disp = NULL;
-	Esnprintf(s, sizeof(s), "exec %s -display %s",
-		  atword(params, 2), dstr);
+	Esnprintf(s, sizeof(s), "exec %s -display %s", atword(params, 2), dstr);
 	execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
      }
    else if (!strcmp(s, "restart"))
@@ -1208,15 +1322,18 @@ doSMExit(void *params)
 	     if (sm_client_id)
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i -theme %s "
+			  "-econfdir %s -ecachedir %s "
 			  "-smfile %s -smid %s -display %s",
 			  command, init_win_ext, themename,
+			  UserEDir(), UserCacheDir(),
 			  sm_file, sm_client_id, dstr);
 	     else
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i -theme %s "
+			  "-econfdir %s -ecachedir %s "
 			  "-smfile %s -display %s",
 			  command, init_win_ext, themename,
-			  sm_file, dstr);
+			  UserEDir(), UserCacheDir(), sm_file, dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
 	  }
 	else
@@ -1224,15 +1341,18 @@ doSMExit(void *params)
 	     if (sm_client_id)
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i "
+			  "-econfdir %s -ecachedir %s "
 			  "-smfile %s -smid %s -display %s",
 			  command, init_win_ext,
+			  UserEDir(), UserCacheDir(),
 			  sm_file, sm_client_id, dstr);
 	     else
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i"
+			  "-econfdir %s -ecachedir %s "
 			  "-smfile %s -display %s",
 			  command, init_win_ext,
-			  sm_file, dstr);
+			  UserEDir(), UserCacheDir(), sm_file, dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
 	  }
      }
@@ -1253,15 +1373,17 @@ doSMExit(void *params)
 	if (sm_client_id)
 	   Esnprintf(s, sizeof(s),
 		     "exec %s -single -ext_init_win %i -theme %s "
+		     "-econfdir %s -ecachedir %s "
 		     "-smfile %s -smid %s -display %s",
 		     command, init_win_ext, userthemepath,
-		     sm_file, sm_client_id, dstr);
+		     UserEDir(), UserCacheDir(), sm_file, sm_client_id, dstr);
 	else
 	   Esnprintf(s, sizeof(s),
 		     "exec %s -ext_init_win %i -theme %s "
+		     "-econfdir %s -ecachedir %s "
 		     "-smfile %s -single -display %s",
 		     command, init_win_ext, userthemepath,
-		     sm_file, dstr);
+		     UserEDir(), UserCacheDir(), sm_file, dstr);
 	execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
      }
    else if (!strcmp((char *)s, "error"))
