@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -218,16 +218,16 @@ SetupX()
    /* if cannot connect to display */
    if (!disp)
      {
-	Alert("Enlightenment cannot connect to the display nominated by\n"
-	      "your shell's DISPLAY environment variable. You may set this\n"
-	      "variable to indicate which display name Enlightenment is to\n"
-	      "connect to. It may be that you do not have an Xserver already\n"
-	      "running to serve that Display connection, or that you do not\n"
-	      "have permission to connect to that display. Please make sure\n"
-	      "all is correct before trying again. Run an Xserver by running\n"
-	      "xdm or startx first, or contact your local system\n"
-	      "administrator, or Xserver vendor, or read the X, xdm and\n"
-	      "startx manual pages before proceeding.\n");
+	Alert(_("Enlightenment cannot connect to the display nominated by\n"
+		"your shell's DISPLAY environment variable. You may set this\n"
+		"variable to indicate which display name Enlightenment is to\n"
+		"connect to. It may be that you do not have an Xserver already\n"
+		"running to serve that Display connection, or that you do not\n"
+		"have permission to connect to that display. Please make sure\n"
+		"all is correct before trying again. Run an Xserver by running\n"
+		"xdm or startx first, or contact your local system\n"
+		"administrator, or Xserver vendor, or read the X, xdm and\n"
+		"startx manual pages before proceeding.\n"));
 	EExit((void *)1);
      }
    root.scr = DefaultScreen(disp);
@@ -272,7 +272,8 @@ SetupX()
 			    if (NULL != dispstr)
 			       *dispstr = '\0';
 			 }
-		       Esnprintf(subdisplay + strlen(subdisplay), 255, ".%d", i);
+		       Esnprintf(subdisplay + strlen(subdisplay), 255, ".%d",
+				 i);
 		       dstr = duplicate(subdisplay);
 		       disp = XOpenDisplay(dstr);
 		       root.scr = i;
@@ -289,18 +290,15 @@ SetupX()
    /* Check for the Shape Extension */
    if (!XShapeQueryExtension(disp, &shape_event_base, &shape_error_base))
      {
-	ASSIGN_ALERT("X server setup error",
-		     "",
-		     "",
-		     "Quit Enlightenment");
-	Alert("FATAL ERROR:\n"
-	      "\n"
-	      "This Xserver does not support the Shape extension.\n"
-	      "This is required for Enlightenment to run.\n"
-	      "\n"
-	      "Your Xserver probably is too old or mis-configured.\n"
-	      "\n"
-	      "Exiting.\n");
+	ASSIGN_ALERT(_("X server setup error"),
+		     "", "", _("Quit Enlightenment"));
+	Alert(_("FATAL ERROR:\n"
+		"\n"
+		"This Xserver does not support the Shape extension.\n"
+		"This is required for Enlightenment to run.\n"
+		"\n"
+		"Your Xserver probably is too old or mis-configured.\n"
+		"\n" "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
@@ -326,32 +324,24 @@ SetupX()
    id = Imlib_init(disp);
    if (!id)
      {
-	ASSIGN_ALERT("Imlib initialisation error",
-		     "",
-		     "",
-		     "Quit Enlightenment");
-	Alert("FATAL ERROR:\n"
-	      "\n"
-	      "Enlightenment is unable to initialise Imlib.\n"
-	      "\n"
-	      "This is unusual. Unable to contiune.\n"
-	      "Exiting.\n");
+	ASSIGN_ALERT(_("Imlib initialisation error"),
+		     "", "", _("Quit Enlightenment"));
+	Alert(_("FATAL ERROR:\n"
+		"\n"
+		"Enlightenment is unable to initialise Imlib.\n"
+		"\n" "This is unusual. Unable to continue.\n" "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
    fd = Fnlib_init(id);
    if (!fd)
      {
-	ASSIGN_ALERT("X server setup error",
-		     "",
-		     "",
-		     "Quit Enlightenment");
-	Alert("FATAL ERROR:\n"
-	      "\n"
-	      "Enlightenment is unable to initialise Fnlib.\n"
-	      "\n"
-	      "This is unusual. Unable to contiune.\n"
-	      "Exiting.\n");
+	ASSIGN_ALERT(_("X server setup error"),
+		     "", "", _("Quit Enlightenment"));
+	Alert(_("FATAL ERROR:\n"
+		"\n"
+		"Enlightenment is unable to initialise Fnlib.\n"
+		"\n" "This is unusual. Unable to continue.\n" "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
@@ -398,11 +388,9 @@ SetupX()
       bpress_win = ECreateWindow(root.win, -80, -80, 24, 24, 0);
       val = bpress_win;
       XChangeProperty(disp, root.win, atom_set, XA_CARDINAL,
-		      32, PropModeReplace,
-		      (unsigned char *)&val, 1);
+		      32, PropModeReplace, (unsigned char *)&val, 1);
       XChangeProperty(disp, bpress_win, atom_set, XA_CARDINAL,
-		      32, PropModeReplace,
-		      (unsigned char *)&val, 1);
+		      32, PropModeReplace, (unsigned char *)&val, 1);
    }
 
    XSync(disp, False);
@@ -410,17 +398,14 @@ SetupX()
    /* warn, if necessary about X version problems */
    if (ProtocolVersion(disp) != 11)
      {
-	ASSIGN_ALERT("X server version error",
-		     "Ignore this error",
-		     "",
-		     "Quit Enlightenment");
-	Alert("WARNING:\n"
-	      "This is not an X11 Xserver. It infact talks the X%i protocol.\n"
-	      "This may mean Enlightenment will either not function, or\n"
-	      "function incorrectly. If it is later than X11, then your\n"
-	      "server is one the author of Enlightenment neither have\n"
-	      "access to, nor have heard of.\n",
-	      ProtocolVersion(disp));
+	ASSIGN_ALERT(_("X server version error"),
+		     _("Ignore this error"), "", _("Quit Enlightenment"));
+	Alert(_("WARNING:\n"
+		"This is not an X11 Xserver. It in fact talks the X%i protocol.\n"
+		"This may mean Enlightenment will either not function, or\n"
+		"function incorrectly. If it is later than X11, then your\n"
+		"server is one the author of Enlightenment neither have\n"
+		"access to, nor have heard of.\n"), ProtocolVersion(disp));
 	RESET_ALERT;
      }
    /* now we'll set the locale */
@@ -447,8 +432,7 @@ SetupX()
       XModifierKeymap    *mod;
       KeyCode             nl, sl;
       int                 i;
-      int                 masks[8] =
-      {
+      int                 masks[8] = {
 	 ShiftMask, LockMask, ControlMask, Mod1Mask, Mod2Mask, Mod3Mask,
 	 Mod4Mask, Mod5Mask
       };
@@ -479,9 +463,9 @@ SetupX()
 	 XFree(mod);
    }
    /* Now we're going to set a bunch of default settings in E - in case we
-    * * don't ever get to load a config file for some odd reason.
-    * * Also, we'll take this opportunity to initialize all of our
-    * * important state variables.
+    * don't ever get to load a config file for some odd reason.
+    * Also, we'll take this opportunity to initialize all of our
+    * important state variables.
     */
 
    mode.next_move_x_plus = 0;
@@ -493,7 +477,7 @@ SetupX()
    mode.place = 0;
    mode.flipp = 0;
    mode.startup = 1;
-   mode.xselect = 1;
+   mode.xselect = 0;
    mode.ewin = NULL;
    mode.button = NULL;
    mode.have_place_grab = 0;
@@ -503,6 +487,9 @@ SetupX()
    mode.x = 0;
    mode.y = 0;
    mode.showroottooltip = 1;
+   mode.pager_sel_button = 2;
+   mode.pager_win_button = 1;
+   mode.pager_menu_button = 3;
    mode.focusmode = FOCUS_SLOPPY;
    mode.focuswin = NULL;
    mode.realfocuswin = NULL;
@@ -542,6 +529,7 @@ SetupX()
       mode.cur_menu[i] = NULL;
    mode.menuslide = 0;
    mode.menusonscreen = 1;
+   mode.warpmenus = 1;
    mode.numdesktops = 2;
    mode.transientsfollowleader = 1;
    mode.switchfortransientmap = 1;
@@ -567,6 +555,10 @@ SetupX()
    mode.display_warp = 0;
 #endif /* WITH_TARTY_WARP */
    mode.warp_on_next_focus = 0;
+   mode.warpsticky = 1;
+   mode.warpshaded = 1;
+   mode.warpiconified = 0;
+   mode.warpfocused = 1;
    mode.edge_flip_resistance = 15;
    mode.context_ewin = NULL;
    mode.moveresize_pending_ewin = NULL;
@@ -604,6 +596,8 @@ SetupX()
    mode.group_config.stick = 1;
    mode.group_config.shade = 1;
    mode.group_config.mirror = 1;
+   mode.area_wraparound = 0;
+   mode.dialog_headers = 0;
    mode.clickalways = 0;
    mode.keybinds_changed = 0;
 
@@ -616,6 +610,14 @@ SetupX()
    desks.hiqualitybg = 1;
    SetAreaSize(2, 1);
 
+#ifdef HAS_XINERAMA
+   {
+
+      xinerama_active = XineramaIsActive(disp);
+
+   }
+#endif
+
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; task_menu[i++] = NULL);
 
    EDBUG_RETURN_;
@@ -628,37 +630,32 @@ ChkDir(char *d)
 {
    if (!isdir(d))
      {
-	Alert("The directory %s is apparently not a directory\n"
-	      "This is a fatal condition.\n"
-	      "Please remove this file\n",
-	      d);
+	Alert(_("The directory %s is apparently not a directory\n"
+		"This is a fatal condition.\n" "Please remove this file\n"), d);
 	EExit((void *)1);
      }
    if (!canexec(d))
      {
-	Alert("Do not have execute access to %s\n"
-	      "This is a fatal condition.\n"
-	      "Please check the ownership and permissions of this\n"
-	      "directory and take steps to rectify this.\n",
-	      d);
+	Alert(_("Do not have execute access to %s\n"
+		"This is a fatal condition.\n"
+		"Please check the ownership and permissions of this\n"
+		"directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
    if (!canread(d))
      {
-	Alert("Do not have read access to %s\n"
-	      "This is a fatal condition.\n"
-	      "Please check the ownership and permissions of this\n"
-	      "directory and take steps to rectify this.\n",
-	      d);
+	Alert(_("Do not have read access to %s\n"
+		"This is a fatal condition.\n"
+		"Please check the ownership and permissions of this\n"
+		"directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
    if (!canwrite(d))
      {
-	Alert("Do not have write access to %s\n"
-	      "This is a fatal condition.\n"
-	      "Please check the ownership and permissions of this\n"
-	      "directory and take steps to rectify this.\n",
-	      d);
+	Alert(_("Do not have write access to %s\n"
+		"This is a fatal condition.\n"
+		"Please check the ownership and permissions of this\n"
+		"directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
 }
@@ -699,27 +696,27 @@ SetupDirs()
       md(s);
    else
       ChkDir(s);
-   Esnprintf(s, sizeof(s), "%s/cached", UserEDir());
+   Esnprintf(s, sizeof(s), "%s/cached", UserCacheDir());
    if (!exists(s))
       md(s);
    else
       ChkDir(s);
-   Esnprintf(s, sizeof(s), "%s/cached/img", UserEDir());
+   Esnprintf(s, sizeof(s), "%s/cached/img", UserCacheDir());
    if (!exists(s))
       md(s);
    else
       ChkDir(s);
-   Esnprintf(s, sizeof(s), "%s/cached/cfg", UserEDir());
+   Esnprintf(s, sizeof(s), "%s/cached/cfg", UserCacheDir());
    if (!exists(s))
       md(s);
    else
       ChkDir(s);
-   Esnprintf(s, sizeof(s), "%s/cached/bgsel", UserEDir());
+   Esnprintf(s, sizeof(s), "%s/cached/bgsel", UserCacheDir());
    if (!exists(s))
       md(s);
    else
       ChkDir(s);
-   Esnprintf(s, sizeof(s), "%s/cached/pager", UserEDir());
+   Esnprintf(s, sizeof(s), "%s/cached/pager", UserCacheDir());
    if (!exists(s))
       md(s);
    else
@@ -745,6 +742,8 @@ SetupEnv()
    Esnprintf(s, sizeof(s), "%i", getpid());
    Esetenv("EPID", s, 1);
    Esetenv("ETHEME", themepath, 1);
+   Esetenv("ECONFDIR", UserEDir(), 1);
+   Esetenv("ECACHEDIR", UserCacheDir(), 1);
 
 #ifdef __EMX__
    Esetenv("EMXSHELL", "sh.exe", 1);
@@ -822,9 +821,9 @@ MakeExtInitWin(void)
    attr.background_pixel = 0;
    attr.save_under = True;
    win = XCreateWindow(d2, root.win, 0, 0, root.w, root.h, 0, root.depth,
-		     InputOutput, root.vis, CWOverrideRedirect | CWSaveUnder |
-		    CWBackingStore | CWColormap | CWBackPixel | CWBorderPixel,
-		       &attr);
+		       InputOutput, root.vis,
+		       CWOverrideRedirect | CWSaveUnder | CWBackingStore |
+		       CWColormap | CWBackPixel | CWBorderPixel, &attr);
    pmap = ECreatePixmap(d2, win, root.w, root.h, root.depth);
    gcv.subwindow_mode = IncludeInferiors;
    gc = XCreateGC(d2, win, GCSubwindowMode, &gcv);
@@ -914,8 +913,8 @@ MakeExtInitWin(void)
 		  pmap = Imlib_move_image(imd, im);
 		  mask = Imlib_move_mask(imd, im);
 		  Imlib_destroy_image(imd, im);
-		  EShapeCombineMask(d2, w2, ShapeBounding, 0, 0,
-				    mask, ShapeSet);
+		  EShapeCombineMask(d2, w2, ShapeBounding, 0, 0, mask,
+				    ShapeSet);
 		  ESetWindowBackgroundPixmap(d2, w2, pmap);
 		  Imlib_free_pixmap(imd, pmap);
 		  XClearWindow(d2, w2);
@@ -923,8 +922,7 @@ MakeExtInitWin(void)
 		  EMoveResizeWindow(d2, w2,
 				    x - (im->rgb_width / 2),
 				    y - (im->rgb_height / 2),
-				    im->rgb_width,
-				    im->rgb_height);
+				    im->rgb_width, im->rgb_height);
 		  EMapWindow(d2, w2);
 	       }
 	     tv.tv_sec = 0;
