@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -57,20 +57,58 @@ MaxHeight(EWin * ewin, char *resize_type)
 		       y1 = 0;
 		       y2 = root.h;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].y_org > y1)
+						  {
+						     y1 = screens[i].y_org;
+						  }
+						if (screens[i].y_org +
+						    screens[i].height < y2)
+						  {
+						     y2 = screens[i].y_org +
+							screens[i].height;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (lst[i] != ewin) &&
-			   (!(lst[i]->ignorearrange)) &&
-			 SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w))
+		       if (
+			   (((ewin->desktop
+			      == lst[i]->desktop) && !(lst[i]->iconified))
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (lst[i] != ewin) && (!(lst[i]->ignorearrange))
+			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+					   lst[i]->w))
 			 {
-			    if (((lst[i]->y + lst[i]->h) <= y) &&
-				((lst[i]->y + lst[i]->h) >= y1))
+			    if (((lst[i]->y + lst[i]->h) <= y)
+				&& ((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
-			    else if (((y + h) <= lst[i]->y) &&
-				     (y2 >= lst[i]->y))
+			    else if (((y + h) <= lst[i]->y)
+				     && (y2 >= lst[i]->y))
 			       y2 = lst[i]->y;
 			 }
 		    }
@@ -100,20 +138,58 @@ MaxHeight(EWin * ewin, char *resize_type)
 		       y1 = 0;
 		       y2 = root.h;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].y_org > y1)
+						  {
+						     y1 = screens[i].y_org;
+						  }
+						if (screens[i].y_org +
+						    screens[i].height < y2)
+						  {
+						     y2 = screens[i].y_org +
+							screens[i].height;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (lst[i] != ewin) &&
-			   (lst[i]->never_use_area) &&
-			 SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w))
+		       if (
+			   (((ewin->desktop == lst[i]->desktop)
+			     && !(lst[i]->iconified)) || (lst[i]->sticky))
+			   && (!(lst[i]->floating)) && (lst[i] != ewin)
+			   && (lst[i]->never_use_area)
+			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+					   lst[i]->w))
 			 {
 			    if (((lst[i]->y + lst[i]->h) <= y) &&
 				((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
-			    else if (((y + h) <= lst[i]->y) &&
-				     (y2 >= lst[i]->y))
+			    else if (((y + h) <= lst[i]->y)
+				     && (y2 >= lst[i]->y))
 			       y2 = lst[i]->y;
 			 }
 		    }
@@ -178,20 +254,58 @@ MaxWidth(EWin * ewin, char *resize_type)
 		       x1 = 0;
 		       x2 = root.w;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].x_org > x1)
+						  {
+						     x1 = screens[i].x_org;
+						  }
+						if (screens[i].x_org +
+						    screens[i].width < x2)
+						  {
+						     x2 = screens[i].x_org +
+							screens[i].width;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (lst[i] != ewin) &&
-			   (!(lst[i]->ignorearrange)) &&
-			 SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h))
+		       if (
+			   (((ewin->desktop == lst[i]->desktop)
+			     && !(lst[i]->iconified)) || (lst[i]->sticky))
+			   && (!(lst[i]->floating)) && (lst[i] != ewin)
+			   && (!(lst[i]->ignorearrange))
+			   && SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
+					   lst[i]->h))
 			 {
 			    if (((lst[i]->x + lst[i]->w) <= x) &&
 				((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
-			    else if (((x + w) <= lst[i]->x) &&
-				     (x2 >= lst[i]->x))
+			    else if (((x + w) <= lst[i]->x)
+				     && (x2 >= lst[i]->x))
 			       x2 = lst[i]->x;
 			 }
 		    }
@@ -221,20 +335,57 @@ MaxWidth(EWin * ewin, char *resize_type)
 		       x1 = 0;
 		       x2 = root.w;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].x_org > x1)
+						  {
+						     x1 = screens[i].x_org;
+						  }
+						if (screens[i].x_org +
+						    screens[i].width < x2)
+						  {
+						     x2 = screens[i].x_org +
+							screens[i].width;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
 		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange)) &&
-			   (!(lst[i]->floating)) &&
+			   (!(lst[i]->floating)) && !(lst[i]->iconified) &&
 			   (((ewin->desktop == lst[i]->desktop) &&
 			     (lst[i]->fixedpos)) ||
 			    (lst[i]->sticky)) &&
-			 SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h))
+			   SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h))
 			 {
 			    if (((lst[i]->x + lst[i]->w) <= x) &&
 				((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
-			    else if (((x + w) <= lst[i]->x) &&
-				     (x2 >= lst[i]->x))
+			    else if (((x + w) <= lst[i]->x)
+				     && (x2 >= lst[i]->x))
 			       x2 = lst[i]->x;
 			 }
 		    }
@@ -305,20 +456,68 @@ MaxSize(EWin * ewin, char *resize_type)
 		       y1 = 0;
 		       y2 = root.h;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].x_org > x1)
+						  {
+						     x1 = screens[i].x_org;
+						  }
+						if (screens[i].x_org +
+						    screens[i].width < x2)
+						  {
+						     x2 = screens[i].x_org +
+							screens[i].width;
+						  }
+						if (screens[i].y_org > y1)
+						  {
+						     y1 = screens[i].y_org;
+						  }
+						if (screens[i].y_org +
+						    screens[i].height < y2)
+						  {
+						     y2 = screens[i].y_org +
+							screens[i].height;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (lst[i] != ewin) &&
-			   (!(lst[i]->ignorearrange)) &&
-			 SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w))
+		       if (
+			   (((ewin->desktop == lst[i]->desktop)
+			     && !(lst[i]->iconified)) || (lst[i]->sticky))
+			   && (!(lst[i]->floating)) && (lst[i] != ewin)
+			   && (!(lst[i]->ignorearrange))
+			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+					   lst[i]->w))
 			 {
 			    if (((lst[i]->y + lst[i]->h) <= y) &&
 				((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
-			    else if (((y + h) <= lst[i]->y) &&
-				     (y2 >= lst[i]->y))
+			    else if (((y + h) <= lst[i]->y)
+				     && (y2 >= lst[i]->y))
 			       y2 = lst[i]->y;
 			 }
 		    }
@@ -337,8 +536,8 @@ MaxSize(EWin * ewin, char *resize_type)
 			    if (((lst[i]->x + lst[i]->w) <= x) &&
 				((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
-			    else if (((x + w) <= lst[i]->x) &&
-				     (x2 >= lst[i]->x))
+			    else if (((x + w) <= lst[i]->x)
+				     && (x2 >= lst[i]->x))
 			       x2 = lst[i]->x;
 			 }
 		    }
@@ -374,20 +573,70 @@ MaxSize(EWin * ewin, char *resize_type)
 		       y1 = 0;
 		       y2 = root.h;
 		    }
+#ifdef HAS_XINERAMA
+		  if (xinerama_active)
+		    {
+		       XineramaScreenInfo *screens;
+		       int                 num_screens;
+
+		       screens = XineramaQueryScreens(disp, &num_screens);
+		       for (i = 0; i < num_screens; i++)
+			 {
+			    if (ewin->x >= screens[i].x_org)
+			      {
+				 if (ewin->x <=
+				     (screens[i].width + screens[i].x_org))
+				   {
+				      if (ewin->y >= screens[i].y_org)
+					{
+					   if (ewin->y <=
+					       (screens[i].height +
+						screens[i].y_org))
+					     {
+						if (screens[i].x_org > x1)
+						  {
+						     x1 = screens[i].x_org;
+						  }
+						if (screens[i].x_org +
+						    screens[i].width < x2)
+						  {
+						     x2 = screens[i].x_org +
+							screens[i].width;
+						  }
+						if (screens[i].y_org > y1)
+						  {
+						     y1 = screens[i].y_org;
+						  }
+						if (screens[i].y_org +
+						    screens[i].height < y2)
+						  {
+						     y2 = screens[i].y_org +
+							screens[i].height;
+						  }
+					     }
+					}
+				   }
+			      }
+			 }
+		    }
+#endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange)) &&
-			   (!(lst[i]->floating)) &&
-			   (((ewin->desktop == lst[i]->desktop) &&
-			     (lst[i]->fixedpos)) ||
-			    (lst[i]->sticky)) &&
-			 SPANS_COMMON(ewin->x, ewin->w, lst[i]->x, lst[i]->w))
+		       if (
+			   ((lst[i] != ewin) && (!(lst[i]->ignorearrange))
+			    && !(lst[i]->iconified)) && (!(lst[i]->floating))
+			   &&
+			   (((ewin->desktop
+			      == lst[i]->desktop) && (lst[i]->fixedpos))
+			    || (lst[i]->sticky))
+			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+					   lst[i]->w))
 			 {
 			    if (((lst[i]->y + lst[i]->h) <= y) &&
 				((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
-			    else if (((y + h) <= lst[i]->y) &&
-				     (y2 >= lst[i]->y))
+			    else if (((y + h) <= lst[i]->y)
+				     && (y2 >= lst[i]->y))
 			       y2 = lst[i]->y;
 			 }
 		    }
@@ -406,8 +655,8 @@ MaxSize(EWin * ewin, char *resize_type)
 			    if (((lst[i]->x + lst[i]->w) <= x) &&
 				((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
-			    else if (((x + w) <= lst[i]->x) &&
-				     (x2 >= lst[i]->x))
+			    else if (((x + w) <= lst[i]->x)
+				     && (x2 >= lst[i]->x))
 			       x2 = lst[i]->x;
 			 }
 		    }
