@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -35,7 +35,8 @@ FindSnapshot(EWin * ewin)
    if (ewin->snap)
       return ewin->snap;
    if ((ewin->client.name) && (ewin->client.class))
-      Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name, ewin->client.class);
+      Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name,
+		ewin->client.class);
    else if (ewin->client.title)
       Esnprintf(buf, sizeof(buf), "TITLE.%s", ewin->client.title);
    else
@@ -62,7 +63,8 @@ GetSnapshot(EWin * ewin)
 	char                buf[4096];
 
 	if ((ewin->client.name) && (ewin->client.class))
-	   Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name, ewin->client.class);
+	   Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name,
+		     ewin->client.class);
 	else if (ewin->client.title)
 	   Esnprintf(buf, sizeof(buf), "TITLE.%s", ewin->client.title);
 	sn = NewSnapshot(buf);
@@ -119,6 +121,12 @@ NewSnapshot(char *name)
    sn->groups = NULL;
    sn->num_groups = 0;
    sn->used = 0;
+   sn->use_skiplists = 0;
+   sn->skiptask = 0;
+   sn->skipfocus = 0;
+   sn->skipwinlist = 0;
+   sn->use_neverfocus = 0;
+   sn->neverfocus = 0;
    AddItemEnd(sn, sn->name, 0, LIST_TYPE_SNAPSHOT);
    return sn;
 }
@@ -157,6 +165,12 @@ ClearSnapshot(Snapshot * sn)
       Efree(sn->groups);
    sn->num_groups = 0;
    sn->used = 0;
+   sn->use_skiplists = 0;
+   sn->skiptask = 0;
+   sn->skipfocus = 0;
+   sn->skipwinlist = 0;
+   sn->use_neverfocus = 0;
+   sn->neverfocus = 0;
    ListChangeItemID(LIST_TYPE_SNAPSHOT, sn, 0);
 }
 
@@ -179,6 +193,8 @@ static char         tmp_snap_icon;
 static char         tmp_snap_shade;
 static char         tmp_snap_cmd;
 static char         tmp_snap_group;
+static char         tmp_snap_skiplists;
+static char         tmp_snap_neverfocus;
 
 static void         CB_ApplySnap(int val, void *data);
 static void
@@ -220,6 +236,10 @@ CB_ApplySnap(int val, void *data)
 		SnapshotEwinCmd(ewin);
 	     if (tmp_snap_group)
 		SnapshotEwinGroups(ewin, tmp_snap_group);
+	     if (tmp_snap_skiplists)
+		SnapshotEwinSkipLists(ewin);
+	     if (tmp_snap_neverfocus)
+		SnapshotEwinNeverFocus(ewin);
 	     SaveSnapInfo();
 	  }
      }
@@ -240,31 +260,34 @@ SnapshotEwinDialog(EWin * ewin)
 	return;
      }
    d = CreateDialog("SNAPSHOT_WINDOW");
-   DialogSetTitle(d, "Application attributes");
+   DialogSetTitle(d, _("Remembered Application Attributes"));
 
    table = DialogInitItem(d);
    DialogItemTableSetOptions(table, 4, 0, 0, 0);
-/*
- * di = DialogAddItem(table, DITEM_IMAGE);
- * DialogItemSetPadding(di, 2, 2, 2, 2);
- * DialogItemSetColSpan(di, 2);
- * DialogItemImageSetFile(di, "pix/snapshots.png");
- * 
- * di = DialogAddItem(table, DITEM_TEXT);
- * DialogItemSetColSpan(di, 2);
- * DialogItemSetPadding(di, 2, 2, 2, 2);
- * DialogItemSetFill(di, 1, 0);
- * DialogItemTextSetText(di,
- * "Select the attributes of this\n"
- * "window you wish to Remember\n"
- * "from now on\n");
- * 
- * di = DialogAddItem(table, DITEM_SEPARATOR);
- * DialogItemSetColSpan(di, 4);
- * DialogItemSetPadding(di, 2, 2, 2, 2);
- * DialogItemSetFill(di, 1, 0);
- * DialogItemSeparatorSetOrientation(di, 0);
- */
+
+   if (mode.dialog_headers)
+     {
+	di = DialogAddItem(table, DITEM_IMAGE);
+	DialogItemSetPadding(di, 2, 2, 2, 2);
+	DialogItemSetColSpan(di, 2);
+	DialogItemImageSetFile(di, "pix/snapshots.png");
+
+	di = DialogAddItem(table, DITEM_TEXT);
+	DialogItemSetColSpan(di, 2);
+	DialogItemSetPadding(di, 2, 2, 2, 2);
+	DialogItemSetFill(di, 1, 0);
+	DialogItemTextSetText(di,
+			      _("Select the attributes of this\n"
+				"window you wish to Remember\n"
+				"from now on\n"));
+
+	di = DialogAddItem(table, DITEM_SEPARATOR);
+	DialogItemSetColSpan(di, 4);
+	DialogItemSetPadding(di, 2, 2, 2, 2);
+	DialogItemSetFill(di, 1, 0);
+	DialogItemSeparatorSetOrientation(di, 0);
+     }
+
    sn = ewin->snap;
    tmp_snap_client = ewin->client.win;
 
@@ -278,6 +301,8 @@ SnapshotEwinDialog(EWin * ewin)
    tmp_snap_shade = 0;
    tmp_snap_cmd = 0;
    tmp_snap_group = 0;
+   tmp_snap_skiplists = 0;
+   tmp_snap_neverfocus = 0;
    if (sn)
      {
 	if (sn->border_name)
@@ -300,13 +325,17 @@ SnapshotEwinDialog(EWin * ewin)
 	   tmp_snap_cmd = 1;
 	if (sn->groups)
 	   tmp_snap_group = 1;
+	if (sn->use_skiplists)
+	   tmp_snap_skiplists = 1;
+	if (sn->use_neverfocus)
+	   tmp_snap_neverfocus = 1;
      }
 
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
    DialogItemSetAlign(di, 0, 512);
-   DialogItemTextSetText(di, "Title:");
+   DialogItemTextSetText(di, _("Title:"));
 
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetColSpan(di, 3);
@@ -321,7 +350,7 @@ SnapshotEwinDialog(EWin * ewin)
 	DialogItemSetPadding(di, 2, 2, 2, 2);
 	DialogItemSetFill(di, 1, 0);
 	DialogItemSetAlign(di, 0, 512);
-	DialogItemTextSetText(di, "Name:");
+	DialogItemTextSetText(di, _("Name:"));
 
 	di = DialogAddItem(table, DITEM_TEXT);
 	DialogItemSetColSpan(di, 3);
@@ -337,7 +366,7 @@ SnapshotEwinDialog(EWin * ewin)
 	DialogItemSetPadding(di, 2, 2, 2, 2);
 	DialogItemSetFill(di, 1, 0);
 	DialogItemSetAlign(di, 0, 512);
-	DialogItemTextSetText(di, "Class:");
+	DialogItemTextSetText(di, _("Class:"));
 
 	di = DialogAddItem(table, DITEM_TEXT);
 	DialogItemSetColSpan(di, 3);
@@ -353,7 +382,7 @@ SnapshotEwinDialog(EWin * ewin)
 	DialogItemSetPadding(di, 2, 2, 2, 2);
 	DialogItemSetFill(di, 1, 0);
 	DialogItemSetAlign(di, 0, 512);
-	DialogItemTextSetText(di, "Command:");
+	DialogItemTextSetText(di, _("Command:"));
 
 	di = DialogAddItem(table, DITEM_TEXT);
 	DialogItemSetColSpan(di, 3);
@@ -400,7 +429,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Location");
+   DialogItemCheckButtonSetText(di, _("Location"));
    DialogItemCheckButtonSetState(di, tmp_snap_location);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_location);
 
@@ -408,7 +437,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Border style");
+   DialogItemCheckButtonSetText(di, _("Border style"));
    DialogItemCheckButtonSetState(di, tmp_snap_border);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_border);
 
@@ -416,7 +445,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Size");
+   DialogItemCheckButtonSetText(di, _("Size"));
    DialogItemCheckButtonSetState(di, tmp_snap_size);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_size);
 
@@ -424,7 +453,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Desktop");
+   DialogItemCheckButtonSetText(di, _("Desktop"));
    DialogItemCheckButtonSetState(di, tmp_snap_desktop);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_desktop);
 
@@ -432,7 +461,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Shaded state");
+   DialogItemCheckButtonSetText(di, _("Shaded state"));
    DialogItemCheckButtonSetState(di, tmp_snap_shade);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_shade);
 
@@ -440,7 +469,7 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Sticky state");
+   DialogItemCheckButtonSetText(di, _("Sticky state"));
    DialogItemCheckButtonSetState(di, tmp_snap_sticky);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_sticky);
 
@@ -448,10 +477,27 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetColSpan(di, 2);
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
-   DialogItemCheckButtonSetText(di, "Stacking layer");
+   DialogItemCheckButtonSetText(di, _("Stacking layer"));
    DialogItemCheckButtonSetState(di, tmp_snap_layer);
    DialogItemCheckButtonSetPtr(di, &tmp_snap_layer);
 
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetPadding(di, 2, 2, 2, 2);
+   DialogItemSetFill(di, 1, 0);
+   DialogItemCheckButtonSetText(di, _("Window List Skip"));
+   DialogItemCheckButtonSetState(di, tmp_snap_skiplists);
+   DialogItemCheckButtonSetPtr(di, &tmp_snap_skiplists);
+
+#if 0
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetPadding(di, 2, 2, 2, 2);
+   DialogItemSetFill(di, 1, 0);
+   DialogItemCheckButtonSetText(di, _("Never Focus"));
+   DialogItemCheckButtonSetState(di, tmp_snap_neverfocus);
+   DialogItemCheckButtonSetPtr(di, &tmp_snap_neverfocus);
+#endif
    if (ewin->client.command)
      {
 	char                ok = 1;
@@ -464,23 +510,24 @@ SnapshotEwinDialog(EWin * ewin)
 	if (ok)
 	  {
 	     di = DialogAddItem(table, DITEM_CHECKBUTTON);
-	     DialogItemSetColSpan(di, 2);
+	     DialogItemSetColSpan(di, 4);
 	     DialogItemSetPadding(di, 2, 2, 2, 2);
 	     DialogItemSetFill(di, 1, 0);
-	     DialogItemCheckButtonSetText(di, "Restart application on login");
+	     DialogItemCheckButtonSetText(di,
+					  _("Restart application on login"));
 	     DialogItemCheckButtonSetState(di, tmp_snap_cmd);
 	     DialogItemCheckButtonSetPtr(di, &tmp_snap_cmd);
 	  }
 	else
 	  {
 	     di = DialogAddItem(table, DITEM_NONE);
-	     DialogItemSetColSpan(di, 2);
+	     DialogItemSetColSpan(di, 4);
 	  }
      }
    else
      {
 	di = DialogAddItem(table, DITEM_NONE);
-	DialogItemSetColSpan(di, 2);
+	DialogItemSetColSpan(di, 4);
      }
 
    if (ewin->groups)
@@ -489,7 +536,7 @@ SnapshotEwinDialog(EWin * ewin)
 	DialogItemSetColSpan(di, 4);
 	DialogItemSetPadding(di, 2, 2, 2, 2);
 	DialogItemSetFill(di, 1, 0);
-	DialogItemCheckButtonSetText(di, "Remember this window's group(s)");
+	DialogItemCheckButtonSetText(di, _("Remember this window's group(s)"));
 	DialogItemCheckButtonSetState(di, tmp_snap_group);
 	DialogItemCheckButtonSetPtr(di, &tmp_snap_group);
      }
@@ -500,9 +547,9 @@ SnapshotEwinDialog(EWin * ewin)
    DialogItemSetFill(di, 1, 0);
    DialogItemSeparatorSetOrientation(di, 0);
 
-   DialogAddButton(d, "OK", CB_ApplySnap, 1);
-   DialogAddButton(d, "Apply", CB_ApplySnap, 0);
-   DialogAddButton(d, "Cancel", CB_ApplySnap, 1);
+   DialogAddButton(d, _("OK"), CB_ApplySnap, 1);
+   DialogAddButton(d, _("Apply"), CB_ApplySnap, 0);
+   DialogAddButton(d, _("Close"), CB_ApplySnap, 1);
    DialogSetExitFunction(d, CB_ApplySnap, 2, d);
    DialogBindKey(d, "Escape", CB_ApplySnapEscape, 0, d);
    DialogBindKey(d, "Return", CB_ApplySnap, 0, d);
@@ -600,6 +647,32 @@ SnapshotEwinSticky(EWin * ewin)
    sn->sticky = ewin->sticky;
 }
 
+void
+SnapshotEwinSkipLists(EWin * ewin)
+{
+   Snapshot           *sn;
+
+   sn = GetSnapshot(ewin);
+   if (!sn)
+      return;
+   sn->use_skiplists = 1;
+   sn->skiptask = ewin->skiptask;
+   sn->skipwinlist = ewin->skipwinlist;
+   sn->skipfocus = ewin->skipfocus;
+}
+
+void
+SnapshotEwinNeverFocus(EWin * ewin)
+{
+   Snapshot           *sn;
+
+   sn = GetSnapshot(ewin);
+   if (!sn)
+      return;
+   sn->use_neverfocus = 1;
+   sn->neverfocus = ewin->neverfocus;
+}
+
 void
 SnapshotEwinIcon(EWin * ewin)
 {
@@ -677,7 +750,8 @@ SnapshotEwinGroups(EWin * ewin, char onoff)
      {
 	if (onoff)
 	  {
-	     groups = ListWinGroups(gwins[i], GROUP_SELECT_EWIN_ONLY, &num_groups);
+	     groups =
+		ListWinGroups(gwins[i], GROUP_SELECT_EWIN_ONLY, &num_groups);
 	     if (groups)
 	       {
 		  sn = gwins[i]->snap;
@@ -729,6 +803,8 @@ SnapshotEwinAll(EWin * ewin)
    SnapshotEwinShade(ewin);
    SnapshotEwinCmd(ewin);
    SnapshotEwinGroups(ewin, ewin->num_groups);
+   SnapshotEwinSkipLists(ewin);
+   SnapshotEwinNeverFocus(ewin);
 }
 
 /* unsnapshot any saved info about this ewin */
@@ -739,7 +815,8 @@ UnsnapshotEwin(EWin * ewin)
    char                buf[4096];
 
    if ((ewin->client.name) && (ewin->client.class))
-      Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name, ewin->client.class);
+      Esnprintf(buf, sizeof(buf), "%s.%s", ewin->client.name,
+		ewin->client.class);
    else if (ewin->client.title)
       Esnprintf(buf, sizeof(buf), "TITLE.%s", ewin->client.title);
    else
@@ -748,7 +825,9 @@ UnsnapshotEwin(EWin * ewin)
      {
 	ListChangeItemID(LIST_TYPE_SNAPSHOT, ewin->snap, 0);
 	ewin->snap->used = 0;
-	sn = RemoveItem((char *)ewin->snap, 0, LIST_FINDBY_POINTER, LIST_TYPE_SNAPSHOT);
+	sn =
+	   RemoveItem((char *)ewin->snap, 0, LIST_FINDBY_POINTER,
+		      LIST_TYPE_SNAPSHOT);
 	ewin->snap = NULL;
      }
    else
@@ -767,15 +846,26 @@ UnsnapshotEwin(EWin * ewin)
      }
 }
 
-/* save out all snapped info to disk */
+/* ... combine writes, only save after a timeout */
+
 void
 SaveSnapInfo(void)
+{
+   DoIn("SAVESNAP_TIMEOUT", 5.0, Real_SaveSnapInfo, 0, NULL);
+}
+
+/* save out all snapped info to disk */
+void
+Real_SaveSnapInfo(int dumval, void *dumdat)
 {
    Snapshot          **lst, *sn;
    int                 i, j, num;
    char                buf[4096], s[4096];
    FILE               *f;
 
+   if (dumdat)
+      dumval = 0;
+
    Etmp(s);
    f = fopen(s, "w");
    if (!f)
@@ -800,11 +890,20 @@ SaveSnapInfo(void)
 	     if (sn->use_wh)
 		fprintf(f, "WH: %i %i\n", sn->w, sn->h);
 	     if (sn->use_xy)
-		fprintf(f, "XY: %i %i %i %i\n", sn->x, sn->y, sn->area_x, sn->area_y);
+		fprintf(f, "XY: %i %i %i %i\n", sn->x, sn->y, sn->area_x,
+			sn->area_y);
 	     if (sn->use_layer)
 		fprintf(f, "LAYER: %i\n", sn->layer);
 	     if (sn->use_sticky)
 		fprintf(f, "STICKY: %i\n", sn->sticky);
+	     if (sn->use_skiplists)
+	       {
+		  fprintf(f, "SKIPTASK: %i\n", sn->skiptask);
+		  fprintf(f, "SKIPWINLIST: %i\n", sn->skipwinlist);
+		  fprintf(f, "SKIPFOCUS: %i\n", sn->skipfocus);
+	       }
+	     if (sn->use_neverfocus)
+		fprintf(f, "NEVERFOCUS: %i\n", sn->neverfocus);
 	     if (sn->use_shade)
 		fprintf(f, "SHADE: %i\n", sn->shade);
 	     if (sn->border_name)
@@ -826,7 +925,7 @@ SaveSnapInfo(void)
    rm(buf);
    mv(s, buf);
    if (!isfile(buf))
-      Alert("Error saving snaps file\n");
+      Alert(_("Error saving snaps file\n"));
    SaveGroups();
 }
 
@@ -861,7 +960,8 @@ LoadSnapInfo(void)
 
    Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetSMFile(), root.scr);
    if (!exists(buf))
-      Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetGenericSMFile(), root.scr);
+      Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetGenericSMFile(),
+		root.scr);
 #ifndef __EMX__
    f = fopen(buf, "r");
 #else
@@ -931,8 +1031,8 @@ LoadSnapInfo(void)
 			    if ((res_w - sn->w) <= 0)
 			       sn->x = 0;
 			    else
-			       sn->x = (sn->x * (root.w - sn->w)) /
-				  (res_w - sn->w);
+			       sn->x =
+				  (sn->x * (root.w - sn->w)) / (res_w - sn->w);
 			 }
 		       else
 			 {
@@ -947,8 +1047,8 @@ LoadSnapInfo(void)
 			    if ((res_h - sn->h) <= 0)
 			       sn->y = 0;
 			    else
-			       sn->y = (sn->y * (root.h - sn->h)) /
-				  (res_h - sn->h);
+			       sn->y =
+				  (sn->y * (root.h - sn->h)) / (res_h - sn->h);
 			 }
 		       else
 			 {
@@ -973,6 +1073,30 @@ LoadSnapInfo(void)
 		  word(buf, 2, s);
 		  sn->sticky = atoi(s);
 	       }
+	     else if (!strcmp(s, "SKIPFOCUS:"))
+	       {
+		  sn->use_skiplists = 1;
+		  word(buf, 2, s);
+		  sn->skipfocus = atoi(s);
+	       }
+	     else if (!strcmp(s, "SKIPTASK:"))
+	       {
+		  sn->use_skiplists = 1;
+		  word(buf, 2, s);
+		  sn->skiptask = atoi(s);
+	       }
+	     else if (!strcmp(s, "SKIPWINLIST:"))
+	       {
+		  sn->use_skiplists = 1;
+		  word(buf, 2, s);
+		  sn->skipwinlist = atoi(s);
+	       }
+	     else if (!strcmp(s, "NEVERFOCUS:"))
+	       {
+		  sn->use_neverfocus = 1;
+		  word(buf, 2, s);
+		  sn->neverfocus = atoi(s);
+	       }
 	     else if (!strcmp(s, "SHADE:"))
 	       {
 		  sn->use_shade = 1;
@@ -987,7 +1111,9 @@ LoadSnapInfo(void)
 	       {
 		  word(buf, 2, s);
 		  sn->num_groups++;
-		  sn->groups = Erealloc(sn->groups, sizeof(int) * sn->num_groups);
+		  sn->groups =
+
+		     Erealloc(sn->groups, sizeof(int) * sn->num_groups);
 
 		  sn->groups[sn->num_groups - 1] = atoi(s);
 	       }
@@ -1028,16 +1154,20 @@ MatchEwinToSnapInfo(EWin * ewin)
 	     if (sn->use_desktop)
 	       {
 		  ewin->client.x +=
-		     ((sn->area_x - desks.desk[ewin->desktop].current_area_x) * root.w);
+		     ((sn->area_x - desks.desk[ewin->desktop].current_area_x) *
+		      root.w);
 		  ewin->client.y +=
-		     ((sn->area_y - desks.desk[ewin->desktop].current_area_y) * root.h);
+		     ((sn->area_y - desks.desk[ewin->desktop].current_area_y) *
+		      root.h);
 	       }
 	     else
 	       {
 		  ewin->client.x +=
-		     ((sn->area_x - desks.desk[desks.current].current_area_x) * root.w);
+		     ((sn->area_x - desks.desk[desks.current].current_area_x) *
+		      root.w);
 		  ewin->client.y +=
-		     ((sn->area_y - desks.desk[desks.current].current_area_y) * root.h);
+		     ((sn->area_y - desks.desk[desks.current].current_area_y) *
+		      root.h);
 	       }
 	  }
 	ewin->x = ewin->client.x;
@@ -1050,6 +1180,14 @@ MatchEwinToSnapInfo(EWin * ewin)
       ewin->layer = sn->layer;
    if (sn->use_sticky)
       ewin->sticky = sn->sticky;
+   if (sn->use_skiplists)
+     {
+	ewin->skipfocus = sn->skipfocus;
+	ewin->skiptask = sn->skiptask;
+	ewin->skipwinlist = sn->skipwinlist;
+     }
+   if (sn->use_neverfocus)
+      ewin->neverfocus = sn->neverfocus;
    if (sn->use_shade)
       ewin->shaded = sn->shade;
    if (sn->iclass_name)
@@ -1079,7 +1217,9 @@ MatchEwinToSnapInfo(EWin * ewin)
 	       {
 		  BuildWindowGroup(&ewin, 1);
 		  ewin->groups[ewin->num_groups - 1]->index = sn->groups[i];
-		  ListChangeItemID(LIST_TYPE_GROUP, ewin->groups[ewin->num_groups - 1], sn->groups[i]);
+		  ListChangeItemID(LIST_TYPE_GROUP,
+				   ewin->groups[ewin->num_groups - 1],
+				   sn->groups[i]);
 	       }
 	     else
 		AddEwinToGroup(ewin, g);
@@ -1169,12 +1309,24 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 	       {
 		  if (sn->use_desktop)
 		     MoveEwin(ewin,
-			      sn->x + ((sn->area_x - desks.desk[ewin->desktop].current_area_x) * root.w),
-			      sn->y + ((sn->area_y - desks.desk[ewin->desktop].current_area_y) * root.h));
+			      sn->x +
+			      ((sn->area_x -
+				desks.desk[ewin->desktop].current_area_x) *
+			       root.w),
+			      sn->y +
+			      ((sn->area_y -
+				desks.desk[ewin->desktop].current_area_y) *
+			       root.h));
 		  else
 		     MoveEwin(ewin,
-			      sn->x + ((sn->area_x - desks.desk[desks.current].current_area_x) * root.w),
-			      sn->y + ((sn->area_y - desks.desk[desks.current].current_area_y) * root.h));
+			      sn->x +
+			      ((sn->area_x -
+				desks.desk[desks.current].current_area_x) *
+			       root.w),
+			      sn->y +
+			      ((sn->area_y -
+				desks.desk[desks.current].current_area_y) *
+			       root.h));
 	       }
 	     else
 		MoveEwin(ewin, sn->x, sn->y);
@@ -1192,6 +1344,14 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 	else
 	   MakeWindowUnSticky(ewin);
      }
+   if (sn->use_skiplists)
+     {
+	ewin->skipfocus = sn->skipfocus;
+	ewin->skiptask = sn->skiptask;
+	ewin->skipwinlist = sn->skipwinlist;
+     }
+   if (sn->use_neverfocus)
+      ewin->neverfocus = sn->neverfocus;
    if (sn->use_shade)
      {
 	if (sn->shade)
@@ -1228,7 +1388,9 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 	       {
 		  BuildWindowGroup(&ewin, 1);
 		  ewin->groups[ewin->num_groups - 1]->index = sn->groups[i];
-		  ListChangeItemID(LIST_TYPE_GROUP, ewin->groups[ewin->num_groups - 1], sn->groups[i]);
+		  ListChangeItemID(LIST_TYPE_GROUP,
+				   ewin->groups[ewin->num_groups - 1],
+				   sn->groups[i]);
 	       }
 	     else
 		AddEwinToGroup(ewin, g);
@@ -1249,6 +1411,8 @@ RememberImportantInfoForEwin(EWin * ewin)
 	SnapshotEwinSticky(ewin);
 	SnapshotEwinShade(ewin);
 	SnapshotEwinGroups(ewin, ewin->num_groups);
+	SnapshotEwinSkipLists(ewin);
+	SnapshotEwinNeverFocus(ewin);
 	SaveSnapInfo();
      }
 }
@@ -1274,6 +1438,8 @@ RememberImportantInfoForEwins(EWin * ewin)
 		  SnapshotEwinSticky(gwins[i]);
 		  SnapshotEwinShade(gwins[i]);
 		  SnapshotEwinGroups(gwins[i], gwins[i]->num_groups);
+		  SnapshotEwinSkipLists(gwins[i]);
+		  SnapshotEwinNeverFocus(gwins[i]);
 		  SaveSnapInfo();
 	       }
 	  }
