@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -24,9 +24,9 @@
 #include "conf.h"
 
 ToolTip            *
-CreateToolTip(char *name, ImageClass * ic0, ImageClass * ic1, ImageClass * ic2,
-	      ImageClass * ic3, ImageClass * ic4, TextClass * tclass,
-	      int dist, ImageClass * tooltippic)
+CreateToolTip(char *name, ImageClass * ic0, ImageClass * ic1,
+	      ImageClass * ic2, ImageClass * ic3, ImageClass * ic4,
+	      TextClass * tclass, int dist, ImageClass * tooltippic)
 {
    ToolTip            *tt;
 
@@ -134,14 +134,13 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 {
    int                 i, w = 0, h = 0, ix, iy, iw, ih, dx, dy, xx, yy;
    int                 ww, hh, adx, ady, dist;
-   int                 headline_h = 0, headline_w = 0, icons_width = 0, labels_width = 0,
-                       double_w = 0, temp_w, temp_h;
+   int                 headline_h = 0, headline_w = 0, icons_width =
+      0, labels_width = 0, double_w = 0, temp_w, temp_h;
    ImlibImage         *im;
    char                pq;
    int                *heights = NULL;
    ImageClass         *ic = NULL;
-   int                 cols[10] =
-   {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+   int                 cols[10] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
    EDBUG(5, "ShowToolTip");
    if (!tt)
@@ -162,29 +161,33 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 
 	     if (ac->list[i]->tooltipstring)
 	       {
-		  TextSize(tt->tclass, 0, 0, STATE_NORMAL, ac->list[i]->tooltipstring, &temp_w, &temp_h, 17);
+		  TextSize(tt->tclass, 0, 0, STATE_NORMAL,
+			   ac->list[i]->tooltipstring, &temp_w, &temp_h, 17);
 		  if (temp_w > labels_width)
 		     labels_width = temp_w;
 		  temp_w = 0;
 
 		  if (ac->list[i]->event == EVENT_DOUBLE_DOWN)
 		    {
-		       TextSize(tt->tclass, 0, 0, STATE_NORMAL, "2x", &double_w, &temp_h, 17);
+		       TextSize(tt->tclass, 0, 0, STATE_NORMAL, "2x", &double_w,
+				&temp_h, 17);
 		       if (cols[0] < double_w)
 			  cols[0] = double_w;
 		    }
 
 		  if (ac->list[i]->anybutton)
 		    {
-		       ic = FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_ICLASS);
+		       ic =
+			  FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
+				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       if (!ic)
 			 {
 			    ic = CreateIclass();
 			    ic->norm.normal = CreateImageState();
 			    ic->norm.normal->im_file = "pix/mouse_any.png";
 			    IclassPopulate(ic);
-			    AddItem(ic, "TOOLTIP_MOUSEBUTTON_ANY", 0, LIST_TYPE_ICLASS);
+			    AddItem(ic, "TOOLTIP_MOUSEBUTTON_ANY", 0,
+				    LIST_TYPE_ICLASS);
 			 }
 		       if (ic->norm.normal)
 			  ImageStateRealize(ic->norm.normal);
@@ -193,71 +196,81 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		     switch (ac->list[i]->button)
 		       {
 		       case 1:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_1", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
 			       ic->norm.normal = CreateImageState();
 			       ic->norm.normal->im_file = "pix/mouse_1.png";
 			       IclassPopulate(ic);
-			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_1", 0, LIST_TYPE_ICLASS);
+			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_1", 0,
+				       LIST_TYPE_ICLASS);
 			    }
 			  if (ic->norm.normal)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 2:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_2", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
 			       ic->norm.normal = CreateImageState();
 			       ic->norm.normal->im_file = "pix/mouse_2.png";
 			       IclassPopulate(ic);
-			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_2", 0, LIST_TYPE_ICLASS);
+			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_2", 0,
+				       LIST_TYPE_ICLASS);
 			    }
 			  if (ic->norm.normal)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 3:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_3", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
 			       ic->norm.normal = CreateImageState();
 			       ic->norm.normal->im_file = "pix/mouse_3.png";
 			       IclassPopulate(ic);
-			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_3", 0, LIST_TYPE_ICLASS);
+			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_3", 0,
+				       LIST_TYPE_ICLASS);
 			    }
 			  if (ic->norm.normal)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 4:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_4", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
 			       ic->norm.normal = CreateImageState();
 			       ic->norm.normal->im_file = "pix/mouse_4.png";
 			       IclassPopulate(ic);
-			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_4", 0, LIST_TYPE_ICLASS);
+			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_4", 0,
+				       LIST_TYPE_ICLASS);
 			    }
 			  if (ic->norm.normal)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 5:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_5", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
 			       ic->norm.normal = CreateImageState();
 			       ic->norm.normal->im_file = "pix/mouse_5.png";
 			       IclassPopulate(ic);
-			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_5", 0, LIST_TYPE_ICLASS);
+			       AddItem(ic, "TOOLTIP_MOUSEBUTTON_5", 0,
+				       LIST_TYPE_ICLASS);
 			    }
 			  if (ic->norm.normal)
 			     ImageStateRealize(ic->norm.normal);
@@ -281,15 +294,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    {
 		       if (ac->list[i]->modifiers & ShiftMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_SHIFT", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_SHIFT", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_shift.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_SHIFT", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_SHIFT", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -303,15 +318,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & LockMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_lock.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_LOCK", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_LOCK", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -325,15 +342,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & ControlMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_ctrl.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_CTRL", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_CTRL", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -347,15 +366,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod1Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_mod1.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_MOD1", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_MOD1", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -369,15 +390,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod2Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_mod2.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_MOD2", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_MOD2", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -391,15 +414,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod3Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_mod3.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_MOD3", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_MOD3", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -413,15 +438,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod4Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_mod4.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_MOD4", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_MOD4", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -435,15 +462,17 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod5Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
 				 ic->norm.normal = CreateImageState();
 				 ic->norm.normal->im_file = "pix/key_mod5.png";
 				 IclassPopulate(ic);
-				 AddItem(ic, "TOOLTIP_KEY_MOD5", 0, LIST_TYPE_ICLASS);
+				 AddItem(ic, "TOOLTIP_KEY_MOD5", 0,
+					 LIST_TYPE_ICLASS);
 			      }
 			    if (ic->norm.normal)
 			       ImageStateRealize(ic->norm.normal);
@@ -618,8 +647,7 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 
    /* draw the ordinary tooltip text */
    TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL, text,
-	    xx, tt->iclass->padding.top,
-	    headline_w, headline_h, 17, 512);
+	    xx, tt->iclass->padding.top, headline_w, headline_h, 17, 512);
 
    /* draw the icons and labels, if any */
    if (ac)
@@ -635,19 +663,27 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		  if (ac->list[i]->event == EVENT_DOUBLE_DOWN)
 		    {
 		       TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL, "2x",
-			  xx + iw - double_w, y, double_w, heights[i], 17, 0);
+				xx + iw - double_w, y, double_w, heights[i], 17,
+				0);
 		    }
 		  if (ac->list[i]->anybutton)
 		    {
-		       ic = FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_ICLASS);
+		       ic =
+			  FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
+				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       if (ic)
 			  if (ic->norm.normal->im)
 			    {
 			       Imlib_render(id, ic->norm.normal->im,
-					    ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-			       PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-			       Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					    ic->norm.normal->im->rgb_width,
+					    ic->norm.normal->im->rgb_height);
+			       PastePixmap(disp, tt->win,
+					   Imlib_copy_image(id,
+							    ic->norm.
+							    normal->im),
+					   Imlib_copy_mask(id,
+							   ic->norm.normal->im),
+					   x, y);
 			       x += ic->norm.normal->im->rgb_width;
 			    }
 		    }
@@ -655,67 +691,107 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		     switch (ac->list[i]->button)
 		       {
 		       case 1:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_1", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
 				  Imlib_render(id, ic->norm.normal->im,
-					       ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				  PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-					      Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					       ic->norm.normal->im->rgb_width,
+					       ic->norm.normal->im->rgb_height);
+				  PastePixmap(disp, tt->win,
+					      Imlib_copy_image(id,
+							       ic->norm.
+							       normal->im),
+					      Imlib_copy_mask(id,
+							      ic->norm.
+							      normal->im), x,
+					      y);
 				  x += ic->norm.normal->im->rgb_width;
 			       }
 			  break;
 		       case 2:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_2", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
 				  Imlib_render(id, ic->norm.normal->im,
-					       ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				  PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-					      Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					       ic->norm.normal->im->rgb_width,
+					       ic->norm.normal->im->rgb_height);
+				  PastePixmap(disp, tt->win,
+					      Imlib_copy_image(id,
+							       ic->norm.
+							       normal->im),
+					      Imlib_copy_mask(id,
+							      ic->norm.
+							      normal->im), x,
+					      y);
 				  x += ic->norm.normal->im->rgb_width;
 			       }
 			  break;
 		       case 3:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_3", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
 				  Imlib_render(id, ic->norm.normal->im,
-					       ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				  PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-					      Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					       ic->norm.normal->im->rgb_width,
+					       ic->norm.normal->im->rgb_height);
+				  PastePixmap(disp, tt->win,
+					      Imlib_copy_image(id,
+							       ic->norm.
+							       normal->im),
+					      Imlib_copy_mask(id,
+							      ic->norm.
+							      normal->im), x,
+					      y);
 				  x += ic->norm.normal->im->rgb_width;
 			       }
 			  break;
 		       case 4:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_4", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
 				  Imlib_render(id, ic->norm.normal->im,
-					       ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				  PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-					      Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					       ic->norm.normal->im->rgb_width,
+					       ic->norm.normal->im->rgb_height);
+				  PastePixmap(disp, tt->win,
+					      Imlib_copy_image(id,
+							       ic->norm.
+							       normal->im),
+					      Imlib_copy_mask(id,
+							      ic->norm.
+							      normal->im), x,
+					      y);
 				  x += ic->norm.normal->im->rgb_width;
 			       }
 			  break;
 		       case 5:
-			  ic = FindItem("TOOLTIP_MOUSEBUTTON_5", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			  ic =
+			     FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
+				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
 				  Imlib_render(id, ic->norm.normal->im,
-					       ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				  PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-					      Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+					       ic->norm.normal->im->rgb_width,
+					       ic->norm.normal->im->rgb_height);
+				  PastePixmap(disp, tt->win,
+					      Imlib_copy_image(id,
+							       ic->norm.
+							       normal->im),
+					      Imlib_copy_mask(id,
+							      ic->norm.
+							      normal->im), x,
+					      y);
 				  x += ic->norm.normal->im->rgb_width;
 			       }
 			  break;
@@ -727,119 +803,200 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    {
 		       if (ac->list[i]->modifiers & ShiftMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_SHIFT", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_SHIFT", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & LockMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & ControlMask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod1Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod2Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod3Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod4Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod5Mask)
 			 {
-			    ic = FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_ICLASS);
+			    ic =
+			       FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
 				    Imlib_render(id, ic->norm.normal->im,
-						 ic->norm.normal->im->rgb_width, ic->norm.normal->im->rgb_height);
-				    PastePixmap(disp, tt->win, Imlib_copy_image(id, ic->norm.normal->im),
-						Imlib_copy_mask(id, ic->norm.normal->im), x, y);
+						 ic->norm.normal->im->rgb_width,
+						 ic->norm.normal->
+						 im->rgb_height);
+				    PastePixmap(disp, tt->win,
+						Imlib_copy_image(id,
+								 ic->
+								 norm.normal->
+								 im),
+						Imlib_copy_mask(id,
+								ic->
+								norm.normal->
+								im), x, y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		    }
 
-		  TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL, ac->list[i]->tooltipstring,
+		  TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL,
+			   ac->list[i]->tooltipstring,
 			   tt->iclass->padding.left + icons_width + iw, y,
 			   labels_width, heights[i], 17, 0);
 		  y += heights[i];
@@ -888,9 +1045,9 @@ FreeToolTip(ToolTip * tt)
      {
 	char                stuff[255];
 
-	Esnprintf(stuff, sizeof(stuff), "Error: %u references remain\n",
+	Esnprintf(stuff, sizeof(stuff), _("%u references remain\n"),
 		  tt->ref_count);
-	DIALOG_OK("ToolTip Error", stuff);
+	DIALOG_OK(_("ToolTip Error!"), stuff);
      }
    EDBUG_RETURN_;
 }
