@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -25,18 +25,16 @@
 typedef struct _efont_color_tab EfontColorTable;
 
 struct _efont_color_tab
-  {
-     Colormap            cmap;
+{
+   Colormap            cmap;
 
-     XColor              list[256];
-     unsigned char       match[8][8][8];
-  };
+   XColor              list[256];
+   unsigned char       match[8][8][8];
+};
 
 /*static EfontColorTable *color_tab = NULL; */
-static unsigned char alpha_lut[5] =
-{0, 64, 128, 192, 255};
-static unsigned char bounded_palette[9] =
-{0, 1, 2, 3, 4, 4, 4, 4, 4};
+static unsigned char alpha_lut[5] = { 0, 64, 128, 192, 255 };
+static unsigned char bounded_palette[9] = { 0, 1, 2, 3, 4, 4, 4, 4, 4 };
 
 static TT_Raster_Map *
 create_font_raster(int width, int height)
@@ -136,8 +134,8 @@ calc_size(Efont * f, int *width, int *height, char *text)
 }
 
 static void
-render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f, char *text,
-	    int *xor, int *yor)
+render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f,
+	    char *text, int *xor, int *yor)
 {
    TT_Glyph_Metrics    metrics;
    TT_Instance_Metrics imetrics;
@@ -196,9 +194,7 @@ render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f, char *text,
 	/* was unsigned.                                             */
 
 	if (xmin >= (int)rmap->width ||
-	    ymin >= (int)rmap->rows ||
-	    xmax < 0 ||
-	    ymax < 0)
+	    ymin >= (int)rmap->rows || xmax < 0 || ymax < 0)
 	   continue;
 
 	/* Note that the clipping check is performed _after_ rendering */
@@ -275,7 +271,9 @@ merge_text_16(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
    cb = (col << 3) & 0xf8;
    for (y = 0; y < xim->height; y++)
      {
-	ptr = (unsigned char *)rmap->bitmap + offset_x + ((y + offset_y) * rmap->cols);
+	ptr =
+	   (unsigned char *)rmap->bitmap + offset_x +
+	   ((y + offset_y) * rmap->cols);
 	for (x = 0; x < xim->width; x++)
 	  {
 	     if ((a = alpha_lut[*ptr]) > 0)
@@ -293,7 +291,9 @@ merge_text_16(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
 		       ng = g + ((tmp + (tmp >> 8) + 0x80) >> 8);
 		       tmp = (cb - b) * a;
 		       nb = b + ((tmp + (tmp >> 8) + 0x80) >> 8);
-		       pixel = ((nr & 0xf8) << 8) | ((ng & 0xfc) << 3) | ((nb & 0xf8) >> 3);
+		       pixel =
+			  ((nr & 0xf8) << 8) | ((ng & 0xfc) << 3) | ((nb & 0xf8)
+								     >> 3);
 		       XPutPixel(xim, x, y, pixel);
 		    }
 		  else
@@ -318,7 +318,9 @@ merge_text_15(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
    cb = (col << 3) & 0xf8;
    for (y = 0; y < xim->height; y++)
      {
-	ptr = (unsigned char *)rmap->bitmap + offset_x + ((y + offset_y) * rmap->cols);
+	ptr =
+	   (unsigned char *)rmap->bitmap + offset_x +
+	   ((y + offset_y) * rmap->cols);
 	for (x = 0; x < xim->width; x++)
 	  {
 	     if ((a = alpha_lut[*ptr]) > 0)
@@ -336,7 +338,9 @@ merge_text_15(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
 		       ng = g + ((tmp + (tmp >> 8) + 0x80) >> 8);
 		       tmp = (cb - b) * a;
 		       nb = b + ((tmp + (tmp >> 8) + 0x80) >> 8);
-		       pixel = ((nr & 0xf8) << 7) | ((ng & 0xf8) << 2) | ((nb & 0xf8) >> 3);
+		       pixel =
+			  ((nr & 0xf8) << 7) | ((ng & 0xf8) << 2) | ((nb & 0xf8)
+								     >> 3);
 		       XPutPixel(xim, x, y, pixel);
 		    }
 		  else
@@ -361,7 +365,9 @@ merge_text_24(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
    cb = col & 0xff;
    for (y = 0; y < xim->height; y++)
      {
-	ptr = (unsigned char *)rmap->bitmap + offset_x + ((y + offset_y) * rmap->cols);
+	ptr =
+	   (unsigned char *)rmap->bitmap + offset_x +
+	   ((y + offset_y) * rmap->cols);
 	for (x = 0; x < xim->width; x++)
 	  {
 	     if ((a = alpha_lut[*ptr]) > 0)
@@ -438,7 +444,9 @@ merge_text_1(XImage * xim, TT_Raster_Map * rmap, int offset_x, int offset_y,
 
    for (y = 0; y < xim->height; y++)
      {
-	ptr = (unsigned char *)rmap->bitmap + offset_x + ((y + offset_y) * rmap->cols);
+	ptr =
+	   (unsigned char *)rmap->bitmap + offset_x +
+	   ((y + offset_y) * rmap->cols);
 	for (x = 0; x < xim->width; x++)
 	  {
 	     if (alpha_lut[*ptr] > 2)
@@ -459,8 +467,8 @@ handle_x_error(Display * d, XErrorEvent * ev)
 }
 
 void
-EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
-		  Efont * font, Visual * vis, Colormap cm)
+EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
+		  char *text, Efont * font, Visual * vis, Colormap cm)
 {
    XImage             *xim;
    XShmSegmentInfo     shminfo;
@@ -492,8 +500,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
 	x_error = 0;
 	is_pixmap = 1;
 	EGetGeometry(disp, win, &chld, &rx, &rx,
-		     (unsigned int *)&xatt.width, (unsigned int *)&xatt.height,
-		     (unsigned int *)&rx, (unsigned int *)&xatt.depth);
+		     (unsigned int *)&xatt.width,
+		     (unsigned int *)&xatt.height, (unsigned int *)&rx,
+		     (unsigned int *)&xatt.depth);
 	XFlush(disp);
 	if (x_error)
 	  {
@@ -511,8 +520,7 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
      {
 	XGetWindowAttributes(disp, xatt.root, &ratt);
 	XTranslateCoordinates(disp, win, xatt.root, 0, 0, &rx, &ry, &chld);
-	if ((xatt.map_state != IsViewable) &&
-	    (xatt.backing_store == NotUseful))
+	if ((xatt.map_state != IsViewable) && (xatt.backing_store == NotUseful))
 	  {
 	     destroy_font_raster(rmap);
 	     destroy_font_raster(rtmp);
@@ -596,7 +604,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
 	       {
 		  shm = 0;
 		  XDestroyImage(xim);
-		  xim = XGetImage(disp, win, x, y, width, height, 0xffffffff, ZPixmap);
+		  xim =
+		     XGetImage(disp, win, x, y, width, height, 0xffffffff,
+			       ZPixmap);
 		  XSetErrorHandler((XErrorHandler) erh);
 		  shm_checked = 1;
 	       }
@@ -608,7 +618,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
 		    {
 		       shm = 0;
 		       XDestroyImage(xim);
-		       xim = XGetImage(disp, win, x, y, width, height, 0xffffffff, ZPixmap);
+		       xim =
+			  XGetImage(disp, win, x, y, width, height, 0xffffffff,
+				    ZPixmap);
 		       XSetErrorHandler((XErrorHandler) erh);
 		       shm_checked = 1;
 		    }
@@ -628,7 +640,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
 	       {
 		  shm = 0;
 		  XDestroyImage(xim);
-		  xim = XGetImage(disp, win, x, y, width, height, 0xffffffff, ZPixmap);
+		  xim =
+		     XGetImage(disp, win, x, y, width, height, 0xffffffff,
+			       ZPixmap);
 		  XSetErrorHandler((XErrorHandler) erh);
 		  shm_checked = 1;
 	       }
@@ -646,7 +660,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
 	       {
 		  shm = 0;
 		  XDestroyImage(xim);
-		  xim = XGetImage(disp, win, x, y, width, height, 0xffffffff, ZPixmap);
+		  xim =
+		     XGetImage(disp, win, x, y, width, height, 0xffffffff,
+			       ZPixmap);
 		  shm_checked = 1;
 	       }
 	     XSetErrorHandler((XErrorHandler) erh);
@@ -677,37 +693,42 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
  * }
  * }
  */
-   if (xatt.depth == 16)
+   if (xim)
      {
-	if (id->x.render_depth == 15)
-	   merge_text_15(xim, rmap, clipx, clipy, col);
-	else
-	   merge_text_16(xim, rmap, clipx, clipy, col);
-     }
-   else if ((xatt.depth == 24) || (xatt.depth == 32))
-      merge_text_24(xim, rmap, clipx, clipy, col);
+	if (xatt.depth == 16)
+	  {
+	     if (id->x.render_depth == 15)
+		merge_text_15(xim, rmap, clipx, clipy, col);
+	     else
+		merge_text_16(xim, rmap, clipx, clipy, col);
+	  }
+	else if ((xatt.depth == 24) || (xatt.depth == 32))
+	   merge_text_24(xim, rmap, clipx, clipy, col);
 /*  else if (xatt.depth == 8)
  * merge_text_8(xim, rmap, clipx, clipy, cm, col); */
-   else if (xatt.depth == 15)
-      merge_text_15(xim, rmap, clipx, clipy, col);
-   else if (xatt.depth <= 8)
-      merge_text_1(xim, rmap, clipx, clipy, col);
+	else if (xatt.depth == 15)
+	   merge_text_15(xim, rmap, clipx, clipy, col);
+	else if (xatt.depth <= 8)
+	   merge_text_1(xim, rmap, clipx, clipy, col);
 
-   if (shm)
-      XShmPutImage(disp, win, gc, xim, 0, 0, x, y,
-		   width, height, False);
-   else
-      XPutImage(disp, win, gc, xim, 0, 0, x, y, width, height);
+	if (shm)
+	   XShmPutImage(disp, win, gc, xim, 0, 0, x, y, width, height, False);
+	else
+	   XPutImage(disp, win, gc, xim, 0, 0, x, y, width, height);
+     }
    destroy_font_raster(rmap);
    destroy_font_raster(rtmp);
-   if (shm)
+   if (xim)
      {
-	XSync(disp, False);
-	XShmDetach(disp, &shminfo);
-	shmdt(shminfo.shmaddr);
-	shmctl(shminfo.shmid, IPC_RMID, 0);
+	if (shm)
+	  {
+	     XSync(disp, False);
+	     XShmDetach(disp, &shminfo);
+	     shmdt(shminfo.shmaddr);
+	     shmctl(shminfo.shmid, IPC_RMID, 0);
+	  }
+	XDestroyImage(xim);
      }
-   XDestroyImage(xim);
    cm = 0;
 }
 
@@ -880,7 +901,8 @@ Efont_extents(Efont * f, char *text, int *font_ascent_return,
 	if (text[i + 1] == 0)
 	  {
 	     if (rbearing_return)
-		*rbearing_return = ((gmetrics.bbox.xMax - gmetrics.advance) / 64);
+		*rbearing_return =
+		   ((gmetrics.bbox.xMax - gmetrics.advance) / 64);
 	  }
 	pw += gmetrics.advance / 64;
      }
