@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- * *
+ * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
  * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  * sell copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * *
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies of the Software, its documentation and marketing & publicity
  * materials, and acknowledgment shall be given in the documentation, materials
  * and software packages that this Software was used.
- * *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -63,8 +63,7 @@ ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
    win = XCreateWindow(disp, parent, x, y, w, h, 0, root.depth,
 		       InputOutput, root.vis, CWOverrideRedirect |
 		       CWSaveUnder | CWBackingStore | CWColormap |
-		       CWBackPixmap | CWBorderPixel,
-		       &attr);
+		       CWBackPixmap | CWBorderPixel, &attr);
    xid = NewXID();
    xid->parent = parent;
    xid->win = win;
@@ -261,8 +260,7 @@ EShapeCombineRectangles(Display * d, Window win, int dest, int x, int y,
 	  {
 	     if ((rect[0].x == 0) &&
 		 (rect[0].y == 0) &&
-		 (rect[0].width == xid->w) &&
-		 (rect[0].height == xid->h))
+		 (rect[0].width == xid->w) && (rect[0].height == xid->h))
 	       {
 		  xid->num_rect = 0;
 		  XFree(xid->rects);
@@ -767,9 +765,7 @@ WindowAtXY_0(Window base, int bx, int by, int x, int y)
    wy += by;
 
    if (!((x >= wx) &&
-	 (y >= wy) &&
-	 (x < (int)(wx + ww)) &&
-	 (y < (int)(wy + wh))))
+	 (y >= wy) && (x < (int)(wx + ww)) && (y < (int)(wy + wh))))
       EDBUG_RETURN(0);
 
    if (!XQueryTree(disp, base, &root_win, &parent_win, &list, &num))
